(function() {
    if (window.granskaPluginAlreadyRan) {
	return;
    }
    window.granskaPluginAlreadyRan = true;

    // ---------------------------------------------------------------------------------
    // function whenOrphaned()
    // ---------------------------------------------------------------------------------
    // If we seem to have been orphaned, remove our listeners.
    // ---------------------------------------------------------------------------------
    function whenOrphaned() {
	if(chrome.runtime.onMessage.hasListener(messageFromPanel)) {
	    chrome.runtime.onMessage.removeListener(messageFromPanel);
	}

	for(var i = 0; i < stuffListenedTo.length; i++) {
	    var element = stuffListenedTo[i];
	    element.removeEventListener("change", onEdits);
	    element.removeEventListener("input", onEdits);
	}
	seenTexts = undefined;
	stuffListenedTo = undefined;
	popupMap = undefined;
	suggMap = undefined;
	textsClean = undefined;
    }
    
    // ---------------------------------------------------------------------------------
    // function messageFromPanel(request, sender, sendResponse)
    // ---------------------------------------------------------------------------------
    // When the popup window wants us to do something, this function
    // is called.
    // ---------------------------------------------------------------------------------
    function messageFromPanel(request, sender, sendResponse) {
	if(chrome.runtime.id == undefined) {
	    // we have been orphaned, possibly by the extension reloading?
	    whenOrphaned();
	    return;
	}

	if(request && request.hasOwnProperty("req")) {
	    if(request.req == "startListening") {
		startListening();
	    }

	    if(request.req == "pushCorrectionToPage") {
		pushCorrectionToPage(request.granskaSentences, request.sentIdx, request.errIdx, request.chosenSuggestion, request.elemIdx);
	    }

	    if(request.req == "sendTexts") {
		if(request.force) {
		    sendTexts(sendResponse, true);
		} else {
		    sendTexts(sendResponse, false);
		}
	    }
	}
	
	return true;
    }

    // ---------------------------------------------------------------------------------
    // Keep track of things we are listening to.
    // ---------------------------------------------------------------------------------
    var stuffListenedTo = [];
    
    // ---------------------------------------------------------------------------------
    // Flag to indicate if the text contents have changed since the
    // last time we were asked to send the texts to the popup window.
    // ---------------------------------------------------------------------------------
    var textsClean = true;
    
    // ----------------------------------------------------------------------------------
    // The last value of the setting for showing all sentences or only
    // the ones with errors.
    // ----------------------------------------------------------------------------------
    var showall = true;
    
    // ----------------------------------------------------------------------------------
    // Variables mirroring the ones from the sidepanel. Used to make
    // our dynamically created HTML elements behave correctly when
    // clicked.
    // ----------------------------------------------------------------------------------
    var popupMap = {};
    var suggMap = {};
    var seenTexts = [];

    // ---------------------------------------------------------------------------------
    // function startListening()
    // ---------------------------------------------------------------------------------
    // Look through the HTML and add listeners to any textarea or input elements.
    // ---------------------------------------------------------------------------------
    function startListening() {
	seenTexts = [];
	stuffListenedTo = [];
	popupMap = {};
	suggMap = {};
	textsClean = false;

	var tas = document.getElementsByTagName("textarea");

	for(var t=0; t < tas.length; t++) {
	    var ta = tas[t];
	    var text = ta.value;
	    
	    listenTo(ta);
	}
    
	var inps = document.getElementsByTagName("input");
	for(var t=0; t < inps.length; t++) {
	    var inp = inps[t];
	    if(inp.type == "text") {
		var text = inp.value;

		listenTo(inp);
	    }
	}

	if(seenTexts.length > 0) {
	    newTexts();
	}
	
	return true;
    }

    // ---------------------------------------------------------------------------------
    // function listenTo(element)
    // ---------------------------------------------------------------------------------
    // Listen to changes to the text in this element.
    // ---------------------------------------------------------------------------------
    function listenTo(element) {
	var alreadyListening = false;
	for(var e = 0; e < element.lenght; e++) {
	    if(element === stuffListenedTo[e]) {
		alreadyListening = true;
		break;
	    }
	}

	if(!alreadyListening) {
	    var idx = stuffListenedTo.length;
	    stuffListenedTo.push(element);
	    seenTexts.push({"text":"", "se":false, "granska":[], "html":""});

	    element.addEventListener("change", newTexts);
	    element.addEventListener("input", newTexts);
	    
	} else {
	    console.log("WARNING: Already listening");
	}
    }

    // ---------------------------------------------------------------------------------
    // function newTexts()
    // ---------------------------------------------------------------------------------
    // When the text content in the page has changed, check if we need
    // to call Granska or update the HTML.
    // ---------------------------------------------------------------------------------
    function newTexts() {
	var needToUpdate = false;
	
	for(var idx = 0; idx < stuffListenedTo.length; idx++) {
	    var element = stuffListenedTo[idx];
	    var newT = element.value;
		
	    while(idx >= seenTexts.length) {
		seenTexts.push({"text":"", "se":false, "granska":[], "html":""});
	    }

	    if(seenTexts[idx].text != newT) {
		var se = false;
		if(newT != "") {
		    se = looksLikeSwedish(newT);
		}

		if((!se || newT == "") && (seenTexts[idx].se && seenTexts[idx].text != "")) {
		    needToUpdate = true;
		}
		if(se && newT != "") {
		    needToUpdate = true;
		}
		    
		seenTexts[idx].text = newT;
		seenTexts[idx].se = se;
		seenTexts[idx].html = "";
		seenTexts[idx].granska = [];

		sendToGranska(idx);
	    }
	}
	
	if(needToUpdate) {
	    textsClean = false;
	    chrome.storage.sync.set({"granskaPollFlag":true}); // tell the popup window we have new data	
	}
    }
    
    // ---------------------------------------------------------------------------------
    // function sendTexts(callback)
    // ---------------------------------------------------------------------------------
    // When asked by the popup window, send the text contents we have found.
    // ---------------------------------------------------------------------------------
    function sendTexts(callback, force) {
	chrome.storage.sync.set({"granskaPollFlag":false}); // tell the popup window we have new data

	if(!textsClean || force) {
	    textsClean = true;

	    res = {"st":seenTexts, "pm":popupMap, "sm":suggMap};

	    callback(res);
	}
    }

    // --------------------------------------------------------------------
    // function checkSettings(changes, area)
    // --------------------------------------------------------------------
    // We listen to the local storage, mainly to check if the results
    // should be shown in the panel or on top of Overleaf.
    // --------------------------------------------------------------------
    function checkSettings(changes, area) {
	chrome.storage.sync.get(['granskaOverleafShowall'], function(d) {
	    if((d && d.granskaOverleafShowall)
	       || (!d || d.granskaOverleafShowall === undefined)) {
		if(!showall) {
		    showall = true;
		    redoHTML();
		}
	    } else {
		if(showall) {
		    showall = false;
		    redoHTML();
									 }
	    }
	});
    }

    // ---------------------------------------------------------------------------------
    // function sendToGranska()
    // ---------------------------------------------------------------------------------
    // Sends plain text to Granska. The scrutinized result is returned to
    // the replyFromGranska() function.
    // ---------------------------------------------------------------------------------
    function sendToGranska(idx) {
	var sentences = seenTexts[idx];

	// TODO: what to do if the text length is longer than the Granska size limit?
	
	if (sentences !== undefined && sentences !== "") {
	    callGranska(seenTexts[idx].text, idx);
	}
    }

    // ---------------------------------------------------------------------------------
    // function callGranska()
    // ---------------------------------------------------------------------------------
    // Does the actual API call.
    // ---------------------------------------------------------------------------------
    function callGranska(sentences, idx) {
	if (sentences !== undefined && sentences !== "") {
	    // Tell background.js to send text to Granska
	    chrome.runtime.sendMessage(
		{
		    method: 'POST',
		    action: 'xhttp',
		    data: sentences
		},
		function(responseText) {
		    replyFromGranska(sentences, responseText, idx);
		});
	}
    }


    // ---------------------------------------------------------------------------------
    // function redoHTML()
    // ---------------------------------------------------------------------------------
    // When the settings for which sentences to show, rebuild the HTML.
    // ---------------------------------------------------------------------------------
    function redoHTML() {
	for(var idx = 0; idx < seenTexts.length; idx++) {
	    granskaToHTML(seenTexts[idx].granska, idx);
	}
	
	textsClean = false;
	chrome.storage.sync.set({"granskaPollFlag":true}); // tell the popup window we have new data	
    }
    
    // ---------------------------------------------------------------------------------
    // function replyFromGranska(originalSentences, response, idx)
    // ---------------------------------------------------------------------------------
    // This is the callback function for the Granska API call, returning
    // the grammar checking results.
    // ---------------------------------------------------------------------------------
    function replyFromGranska(originalSentences, response, idx) {
	var gr = parseGranskarResult(response);

	granskaToHTML(gr, idx);

	textsClean = false;
	chrome.storage.sync.set({"granskaPollFlag":true}); // tell the popup window we have new data	
	
	return true;
    }

    // ----------------------------------------------------------------------------------
    // unXML
    // ----------------------------------------------------------------------------------
    // Convert XML escaped characters to their characters.
    // ----------------------------------------------------------------------------------
    function unXML(str) {
	return str.replace(/&amp;/g, "&")
	    .replace(/&lt;/g, "<")
	    .replace(/&gt;/g, ">")
	    .replace(/&quot;/g, "\"")
	    .replace(/&#039;/g, "'");
    }

    // ----------------------------------------------------------------------------------
    // parseGranskaResult(serverReply)
    // ----------------------------------------------------------------------------------
    // Parse the result from the Granska grammar checker and convert
    // the relevant parts into something easily accessible.
    // ----------------------------------------------------------------------------------
    function parseGranskarResult(serverReply) {
	// remove newlines and some HTML encoding to make the regexps below prettier
	var repl = unXML(serverReply).replace(/\n/g, " ");
	
	// find all sentences with markup
	var sentences = repl.match(/<s\sref=".*?<\/s>/g);
	
	if(!sentences) {
	    console.log("WARNING: parseGranskarResult, no sentences:");
	    console.log(repl);
	    return [];
	}
	
	var sentenceTokens = []; // some sentences above will have parser tokenization, with POS-tags and lemmas
	var sentenceErrors = []; // other sentences will contain grammar checker warnings
	
	for(var si = 0; si < sentences.length; si++) {
	    var s = sentences[si];
	    
	    var sentenceId = s.match(/<s ref="([0-9]+)">/);
	    if(sentenceId) {
		sentenceId = parseInt(sentenceId[1]);
	    } else {
		sentenceId = -1;
	    }
	    
	    var words = s.match(/<w\sno="([0-9]+)"\stag="[0-9]+"\slemma="(.+?)">(.*?)<\/w>/g);

	    if(words) { // if this was a tagging and lemma sentence, store the tokens in an array for later
		var tokens = [];

		for(var i = 0; words != null && i < words.length; i++) {
		    var m = words[i].match(/<w\sno="([0-9]+)"\stag="[0-9]+"\slemma="(.+?)">(.*?)<\/w>/);
		    
		    tokens.push([unXML(m[3]), unXML(m[2]), parseInt(m[1])]); // string, lemma, index
		}
		sentenceTokens.push([sentenceId, tokens]);
	    }

	    var errors = s.match(/<gramerror>.*?<\/gramerror>/g);
	    if(errors) { // if this was a grammar checking bundle, find the rule name, suggestions, markings etc.
		var errs = [];
		for(var i = 0; errors != null && i < errors.length; i++) {
		    var e = errors[i];
		    var ruleName = e.match(/<rule>(.*?)<\/rule>/);
		    
		    if(ruleName) {
			ruleName = ruleName[1];
		    } else {
			ruleName = "";
		    }
		    
		    var infoText = e.match(/<info>(.*?)<\/info>/);
		    if(infoText) {
			infoText = infoText[1];
			infoText = infoText.replace(/<emph type="italic">/g, "<em>").replace(/<\/emph>/g, "</em>");
			infoText = infoText.replace(/<emph.*?>/g, "<em>");
		    } else {
			infoText = "";
		    }

		    var suggs = e.match(/<suggestions>(.*?)<\/suggestions>/);
		    var marks = e.match(/<marked_section>(.*?)<\/marked_section>/);

		    var suggestions = [];
		    if(suggs) {
			var ss = suggs[1].match(/<sugg>.*?<\/sugg>/g);
			for(var j = 0; ss && j < ss.length; j++) {
			    var sugg = ss[j].match(/<sugg>(.*?)<\/sugg>/);
			    if(sugg) {
				var temp = sugg[1];

				var lefts = [];
				var next = temp.indexOf("<emph");
				var nextCloser = temp.indexOf("</emph>");
				while(next >= 0) {
				    var end = temp.indexOf(">", next);
				    var sub = temp.substring(next, end + 1);
				    if(sub == "<emph type=\"italic\">") {
					temp = temp.replace(sub, "<em>");
					lefts.push("</em>");
				    } else if(sub == "<emph type=\"green\">") {
					temp = temp.replace(sub, "<span style=\"color:green; pointer-events: none;\">");
					lefts.push("</span>");
				    } else if(sub == "<emph type=\"red\">") {
					temp = temp.replace(sub, "<span style=\"color:red; pointer-events: none;\">");
					lefts.push("</span>");
				    } else {
					temp = temp.replace(sub, "<em>");
					lefts.push("</em>");
				    }
				    
				    next = temp.indexOf("<emph");
				    while(nextCloser > 0 && (nextCloser < next || next < 0)) {
					temp = temp.replace("</emph>", lefts.pop());
					nextCloser = temp.indexOf("</emph>");
				    }
				}
				
				suggestions.push(temp);
			    }
			}
		    }
		    
		    var markings = [];
		    if(marks) {
			var mm = marks[1].match(/<mark\sbegin="[0-9]+"\send="[0-9]+"\/>/g);
			for(var j = 0; mm && j < mm.length; j++) {
			    var marking = mm[j].match(/<mark\sbegin="([0-9]+)"\send="([0-9]+)"\/>/);
			    markings.push([parseInt(marking[1]) - 2, parseInt(marking[2]) - 2]); // Granska error markings seem to be off by 2?
			}
		    }
		    var err = {"name":ruleName, "info":infoText, "suggs":suggestions, "markings":markings};
		    errs.push(err);
		}
		sentenceErrors.push([sentenceId, errs]);
	    }
	}

	for(var e = 0; e < sentenceErrors.length; e++) {
	    var id = sentenceErrors[e][0];

	    for(var s = 0; s < sentenceTokens.length; s++) {
		if(sentenceTokens[s][0] == id) {
		    if(sentenceTokens[s].length <= 2) {
			sentenceTokens[s].push([]);
		    }
		    for(var ee = 0; ee < sentenceErrors[e][1].length; ee++) {
			sentenceTokens[s][2].push(sentenceErrors[e][1][ee]);
		    }
		}
	    }
	}
	
	return sentenceTokens;
    }

    // ----------------------------------------------------------------------------------
    // function granskaToHTML(sentences, idx)
    // ----------------------------------------------------------------------------------
    // Build HTML for the popup window to show, based on the grammar
    // checking results.
    // ----------------------------------------------------------------------------------
    function granskaToHTML(sentences, idx) {
	if(idx < seenTexts.length) {
	    if(sentences == []) {
		seenTexts[idx].granska = sentences;
		seenTexts[idx].html = "";
	    } else if(!seenTexts[idx].se) {
		seenTexts[idx].granska = sentences;
		seenTexts[idx].html = "";		
	    } else {
		var result = "";

		var popid = 0;
		var suggid = 0;
		
		var nextStart=1;
		var latestStart = [];
		
		for(var s = 0; s < sentences.length; s++) {
		    var tokens = sentences[s][1];

		    var errors = [];
		    if(sentences[s].length > 2) {
			errors = sentences[s][2];
		    }

		    if(showall || (errors && errors.length > 0)) {
			
			result += "\n<p>";
			
			var tagged = [];
			var begins = [];
			var ends = [];
			
			for(var t = 0; t < tokens.length; t++) {
			    tagged.push(0);
			    begins.push([]);
			    ends.push([]);
			}

			for(var e = 0; e < errors.length; e++) {
			    var err = errors[e];
			    
			    for(var m = 0; m < err.markings.length; m++) {
				var from = err.markings[m][0];
				var to = err.markings[m][1];

				begins[from].push(e);
				ends[to].push(e);
				
				for(var t = from; t <= to; t++) {
				    tagged[t] = 1;
				}
			    }
			}

			for(var e = 0; e < errors.length; e++) {
			    var err = errors[e];

			    var errHtml = "";
			    if(err.markings.length > 0) {
				errHtml += "<span style=\"color:red\"><i>";
				
				for(var m = 0; m < err.markings.length; m++) {
				    var from = err.markings[m][0];
				    var to = err.markings[m][1];
				    
				    if(m > 0) {
					errHtml += "...";
				    }
				    for(var t = from; t <= to; t++) {
					errHtml += tokens[t][0] + " ";
				    }
				}
				errHtml += "</i>\n</span>\n";
			    }
			    
			    // info text
			    errHtml += "\n<br/>";
			    errHtml += err.info;

			    // suggestions
			    for(var su = 0; su < err.suggs.length; su++) {
				errHtml += "\n<br/>";
				var tmp = err.suggs[su];
				tmp = tmp.replace(/<.*?>/g, "");

				errHtml += "<span id=\"suggid" + idx + "." + suggid +"\" >" + err.suggs[su] + "</span>";
				suggMap["suggid" + idx + "." + suggid] = [s, e, idx, tmp];
				suggid++;
			    }

			    err["html"] = errHtml;
			}

			for(var t = 0; t < tokens.length; t++) {
			    for(var e = 0; e < begins[t].length; e++) {
				result += "\n<div id=\"popid" + idx + "." + popid + "\" class=\"granskaMarkedError\">";

				popupMap["popid" + idx + "." + popid] = "granska" + idx + "." + nextStart;
				popid++;
				
				latestStart.push(nextStart);
				nextStart++;
			    }
			    result += tokens[t][0] + " ";
			    if(ends[t].length > 0) {
				var nextEnd = latestStart.pop();
				var tooltip = "\n<div class=\"granskaPopupText\" id=\"granska" + idx + "." + nextEnd + "\">\n<div class=\"granskaPopupText-content\"";
				
				for(var e = 0; e < ends[t].length; e++) {

				    var err = errors[ends[t][e]];
				    tooltip += err.html;
				}
				result += tooltip;
				result += "\n</div>\n</div> ";
				for(var e = 0; e < ends[t].length; e++) {
				    result += "\n</div> ";
				}
			    }
			}
			
			result += "\n</p>\n";
		    }
		}

		seenTexts[idx].granska = sentences;
		seenTexts[idx].html = result;
	    }
	}
	return result;
    }
    
    // ----------------------------------------------------------------------------------
    // function looksLikeSwedish(text)
    // ----------------------------------------------------------------------------------
    // Guess if a text is in Swedish or not, based on letter trigram
    // statistics from reference texts in Swedish.
    // ----------------------------------------------------------------------------------
    function looksLikeSwedish(text) {
	var refs={"en ":18466," de":12880,"er ":11039,"et ":9901," oc":9886,"tt ":9648,"om ":9443,"ch ":9279,"och":9234,"ar ":8982,"de ":8395,"an ":8236,"för":7843," ha":7599,"att":7133," fö":6934," i ":6924,"det":6734," me":6524,"är ":6345," at":5947," so":5902," in":5873," en":5610,"som":5508,"ing":5231,"ter":5056,"den":4926,"and":4540,"ill":4506,"nde":4473," va":4413,"te ":4391,"ra ":4357,"n s":4315,"ade":4307,"gen":4272," ti":4262,"na ":4226,"var":4179," på":4155,"han":4154," är":4132,"ör ":4032,"r s":3967," st":3895," ja":3891,"på ":3844," sk":3831,"t s":3806,"ag ":3751,"ll ":3718,"ska":3716,"med":3713," si":3695," vi":3683,"nte":3511," av":3508,"til":3505,"ka ":3495,"int":3410,"jag":3367,"lig":3340,"ig ":3298,"r d":3265,"ed ":3252,"on ":3179,"lle":3143,"a s":3114,"av ":3059,"n. ":2973,"ta ":2972,"rna":2955," om":2936," ho":2875,"der":2874," fr":2771,"r a":2740,"ett":2727,"ns ":2722," be":2703,"nge":2688,"sta":2652,"men":2641,"nin":2621," mi":2620,"all":2593,"era":2573," ma":2520,". d":2517,"r h":2489,"t. ":2464,"ans":2428," - ":2422,"ara":2417,"ver":2414,"ste":2395," an":2361,"hon":2359," sa":2354,"t f":2353,"har":2339," ko":2331,"are":2326," he":2322," ka":2294,"n f":2287,"n o":2280,"kan":2270,", s":2243,"r o":2237," ut":2235,"la ":2216,"n h":2214,"re ":2213,"ga ":2213,"r i":2204,"e s":2193,"ten":2188," al":2170,"n a":2165,"r. ":2163,"t h":2160,"man":2156,"n i":2134,"ens":2125,"lla":2113,"t a":2088,"und":2080,"lan":2007,"nna":2006,"n, ":2003,"isk":2000,"ger":1989," li":1986,"ell":1963,"r m":1950,"t i":1922,"så ":1913,"r f":1913,"ng ":1913," et":1897,"in ":1893,"t o":1882,"t d":1870,"ern":1865,"as ":1862,"ler":1861," bl":1857,"tta":1852," vä":1835," så":1825,"r e":1808,"t m":1800,"nne":1796," se":1784,"en.":1779,"gt ":1770,"gar":1769,"t v":1764,"lar":1761,"a. ":1754,"tar":1742," tr":1742,"sig":1739,"ätt":1730,"n m":1722,"ner":1713," sä":1710,"nga":1695,"st ":1694,"igt":1685,"n v":1683,"år ":1667,"ren":1659,"a f":1641," ba":1639,"n d":1637,"upp":1632,"n t":1620," nä":1617,"t, ":1608,"n b":1595,"a o":1586,"a m":1584,"inn":1581,"iga":1565," mo":1563,"kom":1559,"arn":1555,"t b":1552,"r, ":1548,"ång":1547,"tte":1535,"nsk":1533,"i s":1520,"at ":1517,"örs":1514,"sam":1512,"n k":1512,". h":1501,"dra":1500,"tan":1487,"mma":1478,"es ":1475," fi":1464,"e h":1459," re":1459,"ist":1458,"frå":1440,"t ä":1437,"sto":1432," up":1427,"rt ":1425,"bar":1423,"ser":1419,"mer":1410,"ker":1406,"sen":1402,"ent":1401,"a, ":1399,"när":1396,"ad ":1395,"ran":1390," \" ":1385,"yck":1378,"tor":1357,"r v":1349,"dan":1346,"änd":1344," lä":1340,"ion":1339,"ann":1335,"ers":1334,"ock":1332,"sin":1321,"da ":1312," pr":1312,"or ":1311,"r t":1309,"itt":1304," fa":1289," hä":1282," br":1282," nå":1280,"kar":1278,"ber":1274,"e f":1273,"a b":1273,"h s":1266,". m":1266,"äll":1254,"cke":1253,"a t":1248,"a i":1243," sv":1242,"a a":1241,"t t":1240,"e m":1240,"rad":1238," bo":1238,", m":1235,"het":1234,"bli":1229,"a h":1225,"e a":1224,"ts ":1222,"rar":1216,". -":1208," un":1207,"ort":1206,"rin":1205,"g s":1205,"ord":1203," ta":1202,"r b":1200,"enn":1184,"ull":1182,"min":1176,"t p":1169,"str":1169,"ete":1164,"eri":1162,"r p":1160,"a d":1160,"tid":1152,"s s":1152,"ån ":1151,"tio":1148,"e o":1148," ve":1143,"fte":1139,"tal":1137,"nom":1136,"ken":1133,"one":1132,"ige":1131,"lt ":1127,"rån":1121,"g. ":1119,"e. ":1116,"le ":1112,"t e":1106," hu":1106,"öve":1103,"en,":1103," sp":1103,"vis":1097,"n p":1097,"m s":1095,"son":1094,"ndr":1089," gå":1088,"stä":1083,"lin":1082,"nar":1068," må":1068," ge":1066,"nen":1064,"a p":1064,"t k":1062,"art":1062,"omm":1061,"a k":1061,"rst":1059,"res":1052,"del":1050,"n g":1049," kr":1048,"it ":1046,", d":1043,"n ä":1041," el":1040," öv":1038,"d s":1037,"a v":1031,"dag":1029,"mar":1028,"ast":1028,"est":1023,"els":1022,"er.":1017,"n e":1014,"ot ":1012,"vil":1011,"des":1011," sl":1011,"e i":1010,"llt":1008,"kt ":1007,". s":1007,"någ":1006,"äng":1005,"m h":1001,"nd ":998,"rat":997,"et.":996," fo":992,"nst":990," få":989,"dig":988,"kul":987,"rde":983,"n l":982,"ick":976,"nda":970," dä":970,"ati":968,"där":967,"t g":966,"r k":962,"vi ":961,"ven":961,"e d":961,"m d":957," ku":954,"tra":952,"nat":952,"mig":947,"ram":945,"rig":941,"sku":939,"mme":939,"e b":938,". j":936,"tet":935,"lit":935,"kri":934,"å s":930,"kte":930,"hel":930,"cka":925,"t l":923,"r j":923,"id ":922,"akt":922,"e v":916,"age":915,"kon":911," sj":910,"ant":907,"ela":906,"eda":906,"äge":905,"rik":905," ' ":902,"e, ":899,"fin":897," gr":897,"a e":894,"per":892,"amm":891,"e t":890," la":888,"änn":887,"säg":886,"lag":882,"ket":879," än":876,"r n":875,"vet":873,"ons":871," pa":871,"ur ":867,"mot":856,"hen":855,"len":854," do":850,"g i":848,"h d":847,"sti":844,"kti":839," pe":837,"bet":836,"ari":836," di":836,"gra":835,"tad":834,"par":834,"for":832,"cks":831,"tre":830,"ck ":830," du":829,"tis":828,"ina":826,"s f":825,"i d":825,"ågo":822,"eft":819,"n n":817,"spe":815,"s a":815,"äst":814," kl":810,"ite":809,"fra":809,"r l":808," ef":805,"g o":803,"red":798,"let":794,"ris":793,"jäl":790,"kla":787,"ika":787,"ngs":786,"nt ":785,"sko":783,"tro":781," to":777,"vär":774,"r u":774," da":773,"gör":772,"tig":771,"ess":771,"t u":770,"t n":769,"ind":769,"g f":769,"a l":769,"sa ":768,"ikt":765,"uta":763,"ski":760,"öre":755,"vid":755,"erk":755,"e k":755," bi":755,"e p":753," nu":753,"ats":752,"ret":750,"här":750,"skr":747,"mat":747,"rät":745,"stå":743," kä":743,"l s":742,"nad":738,"ins":736,". i":736," gö":736,"s. ":730,"s i":729,"ras":729,"g, ":729,"sar":728,"öra":727,"lse":725,"då ":723," år":723,"bor":720," lå":720,"pro":719," le":719,"s m":718,"el ":716," ty":712,"ets":706,"sla":705,"ono":705,"nis":705,"r g":704,"had":703,"a g":701,"dom":700,"g t":699," ar":699,"tän":698," fl":698,"n r":696," då":696,"m f":694,"lik":694,"a u":693,"oli":690,"ma ":689," ro":689,"n u":688," hö":688," po":687,"vin":686,"g a":681,"nan":680,"s o":679,"er,":678,", o":678,"nu ":676,"gre":675,"d. ":673,"d a":673,"kor":670," tv":670,"ena":669," ny":668,"pel":667,". f":667,"sso":665,"lde":665,"ala":665,"kså":664," jo":664,"m a":662,"väl":661,"m i":661,"nor":659,"get":659,"kän":658,"kun":658,"sva":656,"nas":656,"tur":653,"ske":649," no":648,"rit":646,"pp ":645,"sve":644,"g h":644,"kli":642,"ne ":641,"gon":640,"sät":636,"tat":634," te":633,"än ":632,". e":632,"sit":631,"län":629,"i e":626,"ege":626,"e e":626,", f":625,"vad":624,"lad":623,"täl":622,"h f":622,"lls":621,"vän":620,"du ":620,"rs ":619,"nta":618," åt":616," dr":616,". n":615," ga":615,"bil":614,"liv":612,"lis":612,"end":612,"ust":611,"mel":607," na":607,"trä":606,"eta":606,"a r":605,"iss":602,"h h":602,"gån":602," or":602,"ung":601,"m e":600," kv":600," mä":598,"ale":597," ju":596,"dri":595,". v":594,", e":593,"å d":592,"nes":591,"lev":591,"v d":589,"ert":589,"m m":588,"ssa":585," tä":583,"sjä":582,"m o":581," ne":580,"t r":579,"van":575,". o":575,"ke ":574,"å a":573,"ut ":572,"ike":572,"d d":570,"nni":568,"lut":568,"går":568,"d o":565,"g m":563,"bes":562," my":561,"ldr":560,"älv":559,"em ":559,"kal":558,"erg":556,"a n":556,"sk ":555,"s h":555,"m. ":555,"ide":555," hå":555,"i f":553,"ark":552,"rli":548,"kap":547,"nns":546,"hål":546,"ive":545,"e l":542,"kna":541,"et,":541," sm":541,"sat":540,"å h":539,"s t":537,"åll":535,"å e":535,"ott":534,"s b":533,"orn":530,"i h":530,"t j":527,"mor":527,"ge ":526," ri":526,"oll":525,"kra":525,"jor":522,"gan":522,"rän":521,"m v":519,"ild":516,", h":516,"pen":515,"män":515,"kad":515," hi":515,"ar.":514,"vår":512,"an.":512,"å m":511,"änk":511,"h m":511,"se ":509,"rka":509,"g v":509,"e g":509,"dar":509,"ass":508,"mån":507,"h b":507,"s, ":506,". a":505,"ghe":504,"ekt":504,"iti":503,"san":502," bö":502,"rsk":501,"r r":499,"ate":499,"d m":498,"d f":498,"va ":497,"lat":497,"mil":496,"riv":495,"pla":495,"e ä":495,"ntr":494,"igh":493,"hur":493,"slu":491,"s k":491,"rn ":491,"opp":491,"las":491,"s d":488,"m t":488,"ack":487,"got":486,"ars":486,"rbe":485,"og ":484,"na.":483,"eno":483,"ble":482,"h t":481,"ali":481," sy":480," 19":478,"is ":477,"v s":476,"i b":476,"arb":476,"app":476,"äck":475,"ir ":475,"i m":475," pl":475,"ppa":473,"nse":472,"ald":472,"lir":469,"å f":468,"l. ":468,"bla":468,"ärl":467,"unn":467,"g k":466,"äns":465,"org":461,"m b":461,"h a":461," mö":461,"amt":460,"ilj":458," ol":458,"sik":457,"nti":457,"ss ":456,"ori":455,"vit":453,"r ä":453,"isa":453,"e j":452,"d h":450," sn":449,"i v":447," rä":447,"myc":445,"kni":445,"h k":445,"d e":445,"far":444,"dni":444,"åga":443,"väg":443,"rma":443,"ida":443,"tag":442,"d, ":439,"am ":439,"tri":438,"får":437," fe":437,", b":436,"åt ":435,"dem":434,"rer":433,"l a":433,"bör":433,"erä":432,"ha ":431,"bra":431,"ors":430,", a":430," ru":430,"s p":428,"nli":427,"ton":426,"tin":426,"tel":426,"ppe":423,", v":422,"h v":421," vå":421," ra":421,"run":420,". t":419,"sök":418,"tyc":417,"åst":416," mu":416,"nds":415,"fat":414,", i":414,"s v":413,"s e":412,"rie":412,"eck":412,"led":411,"e u":410,"ått":409,"orm":409,"l o":409,", t":408,"läg":407,"sse":406,"ost":406,"skt":405,"pet":405,"ng.":405,"rot":404,"set":402,"sad":402,"kil":401,"ise":401,"cen":401,". p":401," eg":401,"tni":399,"oma":398,"m k":398,"ar,":398,"a ä":398,"pre":397,"öst":396,"jus":396," ly":396," gu":396,"råg":392,"rke":392,"rd ":392,"l d":392,". b":392,"ora":391,"i t":391,"ame":389," rö":389,"å v":388,"ytt":388,"å t":386,"rta":386,"h l":386,"spr":385,"sna":385,"al ":385,"i k":383,"ev ":383,"tli":382,"aga":382,"tiv":381,"ror":381,"ig.":381," gi":381,"sed":380,"rso":380,"hem":380,"erl":379,"åde":378,"rda":378,"raf":378,"n j":378,"ele":378,"äve":376,"kta":375,"kat":375,"hör":375," bä":375,"två":372,", k":372,"pri":371,"nke":371,"sli":370,"ndl":370,"lån":370,"åte":369,"ron":369,"g b":369,"aka":369," ex":368,"örd":366,"idi":366,"d i":366,"rkl":363,"ndi":363,"kvi":363,"iva":362,"ier":362,"e r":362,"l i":361,"fil":361,"dli":361,"k. ":360,"bok":360,"ute":358,"l h":358,"ik ":358,"fri":358,"åda":357,"val":357,"ana":357,"ode":356,"nal":356,". k":356,"i a":355,"nsa":354,"mit":354,"e n":354,"dde":353,"arl":353," os":353,"ygg":352,"eli":352," fu":352,"s l":351,"hol":351,"örr":350,"örj":350,"sst":350,"pol":350,"mus":350,"h e":350,"ärd":349,"hus":349,"ämn":347,"stu":347,"mås":347,"alt":347,"rte":346,"bak":346,"rum":345,"rol":344,"ont":344,"elt":344," go":344,"stö":343,"rja":343,"mis":343,"änt":342,"fal":342," tu":342," lu":342,"pa ":341,"l m":341,"ine":340,"tör":339,"h i":339," of":339,"kol":338,"gjo":338,"g p":338,"ivi":337," ur":336,"tik":335,"ls ":335,"li ":335,"atu":335," lo":335,"lsk":334,"ien":334,"äl ":331,"met":331,"m j":331,"d b":331,"tom":330,"rti":330,"l f":329,"å b":328,"låt":328,"lni":328,"gs ":328,"rom":327,"beh":326,"rak":325,"m, ":325,"ags":325," dö":325,"ane":324," sö":324,"å k":323,"sak":323,"mod":323,"få ":323,"ani":323,"äga":322,"ttr":322,"ful":322,"fär":321,"ata":321,"use":320,"ra.":320,"na,":320,"l e":320,"fic":320,"eng":320,"ank":320," bå":320,"m p":319,"on.":318,"h g":318,"gna":318,"hän":317,"olk":316,"lic":316,"ära":315,"vå ":315,"s u":315,"rre":315,"ngt":315,"gge":315," gl":315,"tsa":314,"tit":314,"kro":314,"h p":314,"- d":314,"ift":313,"d t":313,"an,":313,"lek":312,"ört":311,", n":311,"usi":308,"rel":307,"ckl":306,"ang":306,"rra":305,"tas":304,"bru":304,"s n":303,"rfö":303," äv":303,"tår":302,"sid":302,"por":302,"m ä":302," gä":302,"uts":301,"oss":301," gj":301,"os ":300,"jan":300,"i l":300,". l":300,"l, ":299,"ria":298,"ård":297,"olo":297,"kas":297,"ägg":296,"lja":296," ni":296," am":296,"tvi":294,"m g":294,"ede":294,", l":294,"ja ":293,"ita":292,"nsi":291,"rne":290,"rld":290,"mt ":290,"k s":290,"nkt":289,"net":288,"d p":288,"bri":288,"lje":287,"pan":286,"gel":286,"aml":286,"ngr":285,"g d":285,"ruk":284,"rts":284,"olm":284,"d v":284," er":284,"räd":283,"lva":283,"on,":282,"å l":281,"yst":281,"ttn":281,"k o":281,"ärn":280,"v e":280,"ola":280,"lun":280,"a å":280,"örf":279,"lst":279,"k, ":279,"ärm":278,"sju":278,"oms":278,"mål":278," lö":278," kö":278,"läs":277,"ene":277,"re.":276,"m n":276,"gru":276,"fan":276,". \"":276,"je ":275,"fta":275,"båd":275," fä":275,"örk":274,"tru":274,"log":274,"kva":274,"d k":274,"aft":274,"lli":273,"kär":273,"ju ":273,"g ä":273,"fas":273,"dis":273,"bro":273,"ban":273,"00 ":273,"röm":272,"rfa":272,"ckt":272,"reg":271,"pas":271,"din":271,"rme":269,"mst":269,"anl":269,"- j":269,"tes":268,"mli":268,"tun":267,"de.":267,"try":266,"rop":266,"lln":266,"che":266,"örb":265,"mas":265,"fly":265,"å g":264,"ure":264,"sis":264,"nka":264,"hjä":264,"dla":264,"avs":264," kn":264,"s r":263,"mes":263,"mal":263,"lyc":263,"ial":263," ig":263,"åre":261,"ärk":261,"tyd":261,"syn":261,"jär":261,"joh":261,"hal":261,"dre":261," ch":261," ca":261,"rsö":260,"ake":260,"v a":259,"näs":259,"lös":259,"kur":259,"iv ":259,"gla":259,"ågr":258,"lv ":258,"hög":258,"dda":258,"ngd":256,"gga":256,"slä":255,"rag":255,"nsl":255,"örl":254," ry":254,"v m":253,"us ":253,"nya":253,"ig,":253," cl":253,"ore":252,"hop":252,"fol":252,"erv":252," hj":252,"ult":251,"sni":251,"sch":251,"fle":251,"ots":250,"od ":249,"mna":249,"ukt":248,"m l":248,"i g":248,"ard":248,"råd":247,"mla":247,"ld ":247,"ilm":247,"g e":247,"vik":246,"lät":246,"gas":246," su":246," fy":246,"trö":245,"mär":245,"h j":245,"äre":244,"lju":244," by":244,"ärt":243,"t ö":243,"iks":243,"emo":243,"arm":243,"ärs":242,"ssi":242,"stn":241,"i n":240,"g u":240,"s g":239,"l v":239,"jer":239,"agn":239,"äls":238,"re,":238,"cla":238,"mun":237,"lti":237,"vec":236,"rek":236,"ral":236,"nfö":236,"h r":236,"edi":236,"a ö":236,"his":234,"byg":234,"ben":234," bu":234,"h n":233,"g l":233,", p":233,"sor":232,"fre":232,", j":232,"rut":231,"or.":231,"lld":231,"kel":231,"lor":230,"eve":230,"öte":229,"ds ":229,", u":229,"sio":228,"rör":228,"tti":227,"sky":227,"g g":227,"n \"":226,"mpe":226,"ilk":226,"ya ":225,"gat":225,"aff":225," id":225,"pra":224,"nno":224,"åg ":223,"å o":223,"sma":223,"roc":223,"her":223,"utt":222,"sty":222,"ng,":222,"n 1":222,"lda":222,"i o":222,"gam":222,"dit":222,"öde":221,"r ö":221,"om.":221,"n ö":221,"gå ":221,"ere":221,"rge":220,"rev":220,"ntl":220,"llb":220,"v f":219,"tna":219,"h o":219,"grä":219,"eln":219,"åka":218,"um ":218,"ude":218,"u s":218,"ote":218,"lie":218,"häl":218,". r":218,"\", ":218," \",":218,"säk":217,"råk":217,"ini":217,"igg":217,"ffa":217,"ia ":216,"- o":216,"ölj":215,"svä":215,"ryc":215,"rep":215,"inf":215,"eme":215,"ako":215,"å i":214,"ndg":214,"i p":214,"dsk":214,"a j":214,"umm":213,"täm":213,"mti":213,"g n":213,"amn":213," tj":213,"å n":212,"rog":212,"de,":212," 2 ":212,"nog":211,"gli":211,"ama":211,"ag.":211,"vat":210,"skä":210,"ie ":210,"huv":210,"öns":209,"tog":209,"tjä":209,"rg ":209,"l b":209,"ft ":209,"lba":208,"ött":207,"ri ":207,"ota":207,"ona":207," lj":207,"små":206,"sda":206,"amh":206,"ta.":205,"spa":205,"sol":205,"rod":205,"lys":205,"les":205,"vud":204,"uvu":204,"rid":204,"dgr":204,"mak":203,"jli":203,"tyr":202,"eni":202," 1 ":202,"v h":201,"tol":201,"tem":201,"rob":201,"ogr":201,"ckh":201,"bre":201,"als":201," pi":201,"öjl":200,"äld":200,"tek":200,"rga":200,"föl":200,"v. ":198,"oft":198,"obe":198,"err":198,"cha":198," äl":198,"v b":196,"tve":196,"rdi":196,"pps":196,"nit":196,"n '":196,"eka":196,"dad":196," sc":196,"toc":195,"oha":195,"git":195,"tt.":194,"möt":194,"lke":194,"l p":194,"kre":194,"arr":194," ce":194,"st.":193,"pek":193,"kam":193,"uto":192,"n å":192,"mfö":192,"ll.":192,"kho":192,"tst":191,"rje":191,"oni":191,"ome":191,"d n":191,"årt":190,"k f":190,"gad":190,"ext":190,"möj":189,"hos":189,"ham":189,"eva":189,"rva":188,"mon":188,"bol":188,"örv":187,"å. ":187,"ond":187,"nel":187,"lta":187,"gis":187,"cer":187,"yra":186,"räc":186,"rss":186," 10":186,"örm":185,"svå":185,"m u":185,"kin":185,"jud":185,"ffe":185,"ädd":184,"ubb":184,"ra,":184,"beg":184,"agi":184," jä":184,"öke":183,"t å":183,"ppt":183,"ads":183,", g":183,"yrk":182,"tsä":182,"oge":182,"lär":182,"k i":182,"ask":182,". g":182," pu":182,"unk":181,"t \"":181,"sal":181," åk":181,"örn":180,"ånd":180,"yll":180,"sag":180,"p. ":180,"n c":180,"lte":180,"lsa":180,"kvä":180,"i i":180,"erh":180,"eko":180,"abb":180,"yss":179,"ove":179,"l t":179,"gic":179,"ehö":179,"arj":179,"ape":179,"ami":179,", ä":179,"äkt":178,"v o":178,"nhe":178,"hit":178,"fem":178,"enh":178,"egr":178,"tsl":177,"nss":177,"gif":177,"bel":177,"adi":177,". u":177,"öka":176,"äsa":176,"tod":176,"pat":176,"ndå":176,"soc":175,"ova":175,"lem":175,"ian":175,"gst":175,"emp":175,"d l":175,"kog":174,"gor":174,"ema":174,"å p":173,"v v":173,"uni":173,"rös":173,"ppl":173,"juk":173,"ino":173,"ges":173,"esk":173,"åta":172,"äde":172,"gne":172,"- s":172,"- m":172," ki":172," \".":172,"äke":171,"urt":171,"pli":171,"omp":171,"fun":171,"edd":171,"\". ":171,"vak":170,"sän":170,"skö":170,"rle":170,"näm":170,"cia":170,"-ta":170,"såd":169,"lam":169,"iet":169,"dik":169,"0-t":169,"\" d":169,"räf":168,"or,":168,"jon":168,"jar":168,"ifr":168,"ids":168,"i r":168,"bba":168," is":168,"tse":167,"rk ":167,"nvä":167,"nd.":167,"lm ":167,"ibl":167,"ese":166,"död":166,"väs":165,"uka":165,"höv":165,"lus":164,"ksa":164,"hun":164,"ety":164,"urs":163,"smä":163,"r å":163,"ngl":163,"l k":163,"kos":163,"erb":163,"arf":163,"älj":162,"unt":162,"fli":162,"erd":162,"emm":162,"örh":161,"r c":161,"imm":161,"god":161,"apa":161,", r":161,"vel":160,"säl":160,"ned":160,"blo":160," th":160,"åna":159,"tim":159,"ogi":159,"ka.":159,"k m":159,"il ":159,"gri":159,"bäs":159,"utv":158,"tys":158,"rsv":158,"ni ":158,"mör":158,"lds":158,"ili":158,"fru":158,"emi":158,"edn":158,"dst":158,". ä":158," ög":158," / ":158,"å, ":157,"n -":157,"ila":157,"ögo":156,"tån":156,"slo":156,"ro ":156,"ält":155,"usa":155,"tie":155,"te.":155,"nsp":155,"nam":155,"mpa":155,"fåt":155,"esl":155,"amp":155,"såg":154,"loc":154,"gäl":154,"esp":154,"eci":154,"doc":154,"rsi":153,"orr":153,"h u":153,"anf":153,"alv":153," ak":153,"uti":152,"oci":152,"lom":152,"lka":152,"io ":152," ci":152,"sys":151,"rem":151,"mäs":151,"gt.":151,"ämt":150,"oke":150,"mta":150,"mmu":150,"läm":150,"e å":150,"dro":150,"- v":150,"örä":149,"sån":149,"sov":149,"nyt":149,"nn ":149,"mmi":149,"ckn":149," em":149,"äff":148,"v k":148,"klä":148,"ire":148,"erm":148,"dd ":148,"agt":148,"v t":147,"u i":147,"nej":147,"lss":147,"krä":147,"fyr":147,"off":146,"nik":146,"läd":146,"lme":146,"kör":146,"ks ":146,"jak":146,"ism":146,"ysk":145,"pos":145,"nap":145,"k a":145,"ink":145,"hår":145,"dju":145,"a \"":145," 20":145,"tak":144,"rup":144,"rla":144,"los":144," ib":144,"rap":143,"oce":143,"iel":143,"ice":143,"d u":143,"år.":142,"uss":142,"ume":142,"tt,":142,"rt.":142,"rav":142,"r \"":142,"ok ":142,"giv":142,"dor":142,". 1":142," dj":142,"åra":141,"omi":141,"oka":141,"lyt":141,"fäl":141,"fer":141,"amf":141,"alm":141," ky":141," bj":141,"ta,":140,"svi":140,"rvi":140,"ric":140,"ong":140,"llr":140,"l 1":140,"bbe":140,"as.":140," op":140,"sme":139,"ole":139,"m r":139,"inl":139,"die":139,"å r":138,"v i":138,"st,":138,"sek":138,"rvä":138,"llv":138,"lid":138,"das":138,"at.":138," 12":138,"åld":137,"utr":137,"p o":137,"ka,":137,"jun":137,"fis":137,"d g":137,"198":137,"rgs":136,"prä":136,"k h":136,"jän":136,"gär":136,"älp":135,"uel":135,"rks":135,"r: ":135,"k t":135,"håk":135,"gni":135,"eld":135,"bär":135,"atr":135,"ag,":135,"the":134,"teg":134,"rov":134,"rea":134,"ndo":134,"gud":134,"t '":133,"ros":133,"rko":133,"rhe":133,"ppn":133,"ope":133,"i. ":133,"fam":133,"eds":133,"drö":133,"u h":132,"nut":132,"gt,":132,"exp":132,"amb":132,"väx":131,"tts":131,"ryg":131,"rus":131,"rsa":131,"r 1":131,"oti":131,"ne.":131,"ilt":131,"ile":131,"ero":131,"bry":131,"a c":131,"åke":130,"ämm":130,"vli":130,"spo":130,"rim":130,"nåt":130,"ltu":130,"car":130,"akn":130,"afi":130," yt":130," wi":130," 18":130,"yre":129,"prå":129,"om,":129,"ny ":129,"i u":129,"enb":129,"dna":129," rå":129," co":129,"vor":128,"tär":128,"sfö":128,"sel":128,"rtr":128,"ppf":128,"köp":128,"ipp":128,"evi":128,"bef":128,"arv":128,"aro":128,"ada":128,"äg ":127,"sex":127,"rsä":127,"fel":127,"erf":127,"dat":127," ih":127,"ökt":126,"utg":126,"tsk":126,"te,":126,"sär":126,"nd,":126,"j, ":126,"g r":126,"cko":126,"anv":126," ov":126,"ärf":125,"tex":125,"slå":125,"rri":125,"rdn":125,"frä":125,"d ä":125,"ad.":125," ag":125," 13":125,"åen":124,"ydd":124,"tec":124,"s ä":124,"rse":124,"rns":124,"rni":124,"odd":124,"kyr":124,"ebr":124,"d r":124,"alo":124," hy":124,"åri":123,"vac":123,"uar":123,"rec":123,"ms ":123,"låg":123,"ja,":123,"ga.":123,"etr":123,"ato":123," wa":123," af":123,"äpp":122,"skå":122,"rlo":122,"pap":122,"gde":122,"esi":122,"bek":122," ek":122,"är.":121,"tfö":121,"skl":121,"rgi":121,"p, ":121,"ll,":121,"klo":121,"ilo":121,"eke":121,"e c":121,"10 ":121,"u ä":120,"ssn":120,"pad":120,"ork":120,"omr":120,"l l":120,"jör":120,"asi":120,"arg":120,"). ":120,"\" s":120," we":120,"v, ":119,"räm":119,"rsl":119,"lms":119,"l n":119,"exe":119," ob":119,"önd":118,"öd ":118,"å j":118,"u v":118,"tud":118,"trå":118,"sut":118,"räl":118,"rto":118,"plö":118,"lts":118,"fak":118,"enl":118," as":118,"ule":117,"röd":117,"rhå":117,"pt ":117,"obb":117,"l g":117,"k p":117,"e ö":117,"ams":117,"ydl":116,"v p":116,"nnu":116,"lko":116,"eti":116,"d j":116," dy":116,"ömm":115,"url":115,"sbe":115,"nab":115,"mbo":115,"lot":115,"kl ":115,"jad":115,"edr":115,"eat":115," 3 ":115,"öts":114,"öpp":114,"ärg":114,"ubl":114,"llf":114,"ktu":114,"kt.":114,"kes":114,"elv":114,"ega":114,"bit":114,"a '":114,"), ":114,"rve":113,"fot":113,"bät":113,"ap ":113,"xem":112,"vem":112,"sjö":112,"pin":112,"opa":112,"mid":112,"löt":112,"lov":112,"ljö":112,"inu":112,"ga,":112,"0 m":112,"öll":111,"års":111,"å u":111,"vt ":111,"räs":111,"rba":111,"niv":111,"mag":111,"gsl":111,"fen":111,"- h":111,"yde":110,"slö":110,"s ö":110,"obl":110,"nt.":110,"nle":110,"mra":110,"ivs":110,"gåt":110,"rkn":109,"pte":109,"nie":109,"mhe":109,"lve":109,"lip":109,"k d":109,"egn":109,"brä":109,"000":109," vo":109,"ud ":108,"tnä":108,"söd":108,"spä":108,"seg":108,"sas":108,"ryt":108,"rkt":108,"rif":108,"ppr":108,"p s":108,"mhä":108,"klu":108,"gsk":108,"ggn":108,"dam":108,"ano":108," on":108,"öjd":107,"öda":107,"ula":107,"räk":107,"rlä":107,"rip":107,"r '":107,"oto":107,"omb":107,"nto":107,"mos":107,"fon":107,"esa":107,". c":107,"'. ":107,"' s":107," '.":107,"lil":106,"jut":106,"itu":106,"ej,":106," öp":106," nö":106,"å ä":105,"ssl":105,"smi":105,"mad":105,"leg":105,"k b":105,"its":105,"hin":105,"enk":105,"dir":105,"bjö":105,"- 1":105," if":105,"vag":104,"v r":104,"uds":104,"tfa":104,"rtf":104,"rm ":104,"pna":104,"p m":104,"må ":104,"gin":104,"ek ":104,"edv":104,"dje":104,"deb":104,"bju":104," 11":104,"öru":103,"åla":103,"vri":103,"ugg":103,"tac":103,"sön":103,"rl ":103,"ref":103,"läk":103,"kus":103,"iho":103,"i, ":103,"avg":103," 15":103,"ävl":102,"är,":102,"utn":102,"tå ":102,"tch":102,"s j":102,"num":102,"msk":102,"kaf":102,"jäm":102,"in.":102,"in,":102,"fyl":102,"duk":102,"- n":102,"xte":101,"v l":101,"t c":101,"ssk":101,"nsv":101,"lna":101,"la.":101,"ils":101,"el.":101,"edl":101," 17":101,"öva":100,"t? ":100,"röt":100,"rmo":100,"ns.":100,"mpo":100,"ldi":100,"gdo":100,"gal":100,"esu":100,"ekn":100,"egi":100,"ärr":99,"vån":99,"una":99,"tyg":99,"top":99,"rt,":99,"rmi":99,"lyg":99,"kt,":99,"gav":99,"dal":99,"da.":99,"vni":98,"uro":98,"spå":98,"rds":98,"op ":98,"n 2":98,"mul":98,"lop":98,"lon":98,"ln ":98,"llo":98,"k v":98,"höj":98,"hot":98,"föd":98,"brö":98,"blå":98,"? d":98," ir":98," 0 ":98,"tea":97,"pub":97,"ple":97,"mrå":97,"kob":97,"idn":97,"hef":97,"h ä":97,"\" o":97," ör":97,"ök ":96,"ynd":96,"vla":96,"tto":96,"ppo":96,"p i":96,"ov ":96,"mpl":96,"mne":96,"lok":96,"kyl":96,"job":96,"jen":96,"ira":96,"idr":96,"eur":96,"erö":96," äg":96," fj":96,"vs ":95,"une":95,"s \"":95,"rio":95,"osi":95,"omk":95,"nba":95,"läp":95,"abr":95," us":95," ev":95,"v n":94,"ut.":94,"t: ":94,"t -":94,"rsp":94,"ljo":94,"äri":93,"tju":93,"rön":93,"råt":93,"kto":93,"ivn":93,"inv":93,"esö":93,"bot":93," ös":93,"ål ":92,"ämp":92,"utb":92,"udi":92,"u f":92,"pp.":92,"me ":92,"kiv":92,"ime":92,"idd":92,"i j":92,"gul":92,"ebo":92,": \"":92," 00":92,"uri":91,"sof":91,"ril":91,"nk ":91,"n? ":91,"lod":91,"epp":91,"a -":91,"0 k":91," 4 ":91,"vol":90,"vde":90,"utf":90,"tvä":90,"pun":90,"osk":90,"o. ":90,"nån":90,"n: ":90,"haf":90,"gtv":90,"fes":90,"ca ":90,"- t":90,"uld":89,"tav":89,"rn.":89,"ppg":89,"o, ":89,"nce":89,"l u":89,"köt":89,"kön":89,"gg ":89,"bal":89,"ave":89,"atc":89,"alk":89," ot":89,"övr":88,"ösa":88,"åli":88,"tus":88,"spi":88,"rgo":88,"r -":88,"kts":88,"jur":88,"inr":88,"gem":88,"ex ":88,"e \"":88,"bat":88,"ava":88,"olv":87,"okr":87,"lvi":87,"jet":87,"fik":87,"dör":87,"cis":87,"bun":87,"bin":87,"bas":87,"ås ":86,"utl":86,"ts.":86,"pän":86,"pis":86,"ose":86,"oly":86,"l r":86,"ido":86,"höl":86,"hov":86,"göt":86,"gun":86,"glö":86,"em.":86,"ehå":86,"efo":86,"bud":86,"bos":86," ön":86," ab":86," 8 ":86,"yng":85,"våg":85,"our":85,"nla":85,"mbe":85,"kso":85,"kop":85,"feb":85,"eha":85," eu":85," ap":85," 5 ":85,"äss":84,"yte":84,"se.":84,"odu":84,"dio":84,"asa":84,". '":84," 14":84," (1":84,"u o":83,"täc":83,"tho":83,"sul":83,"ssu":83,"rym":83,"ntu":83,"ndn":83,"lt.":83,"lk ":83,"kis":83,"iot":83,"gsa":83,"da,":83,"ck.":83,"bac":83,"avl":83,"ago":83,"a? ":83,"30 ":83," il":83,"ve ":82,"u m":82,"u k":82,"rty":82,"rof":82,"r? ":82,"l ä":82,"ich":82,"fad":82,"? h":82,"2 1":82,"12 ":82,"äna":81,"äkn":81,"tue":81,"skn":81,"rök":81,"rys":81,"rab":81,"pår":81,"n (":81,"gsm":81,"eks":81,"een":81,"edj":81,"bio":81,"ak ":81," im":81,"åle":80,"äse":80,"äms":80,"yta":80,"sur":80,"räv":80,"old":80,"nre":80,"ndb":80,"k k":80,"k e":80,"- e":80," je":80,"sha":79,"lör":79,"ept":79,"at,":79,"amr":79,"-år":79,"- f":79," ps":79,"ön ":78,"år,":78,"äml":78,"urn":78,"röv":78,"pon":78,"ovi":78,"onk":78,"nt,":78,"nkl":78,"nic":78,"mäl":78,"lår":78,"lof":78,"lim":78,"kot":78,"inb":78,"gsp":78,"gsf":78,"fab":78,"dve":78,"13 ":78,"täv":77,"sun":77,"s '":77,"rmå":77,"rgå":77,"llk":77,"käm":77,"käl":77,"ik.":77,"grå":77,"eto":77,"eth":77,"ed.":77," 50":77," 16":77,"u, ":76,"stl":76,"rr ":76,"mni":76,"lå ":76,"lra":76,"kåd":76,"kry":76,"irk":76,"imi":76,"h c":76,"eor":76,"eal":76,"bus":76,"avi":76,"15 ":76,"\" e":76," ke":76,"yft":75,"ura":75,"ugn":75,"udd":75,"u t":75,"tåe":75,"tum":75,"siv":75,"rbr":75,"ofi":75,"odi":75,"nje":75,"mam":75,"isi":75,"i ö":75,"g å":75,"efi":75,"dvi":75,"dia":75,"50 ":75," ök":75,"öt ":74,"öck":74,"ärv":74,"tså":74,"ti ":74,"tab":74,"rua":74,"rbi":74,"oso":74,"ojk":74,"ngo":74,"lås":74,"k ä":74,"emb":74,"eba":74,"e -":74,"bon":74,"bev":74,"ad,":74,"', ":74," ',":74,"v u":73,"v g":73,"teb":73,"tam":73,"stj":73,"sce":73,"s å":73,"reb":73,"nvi":73,"nil":73,"mn ":73,"lma":73,"la,":73,"kit":73,"k l":73,"ivt":73,"imp":73,"i ä":73,"g ö":73,"20 ":73,"...":73,"ödd":72,"v j":72,"uns":72,"ump":72,"uft":72,"u b":72,"taf":72,"poj":72,"poe":72,"ohn":72,"neh":72,"lön":72,"luf":72,"ked":72,"gus":72,"esv":72,"elb":72,"dss":72,"dot":72,"don":72,"agl":72," a ":72,"ös ":71,"öri":71,"vsl":71,"vic":71,"tot":71,"t 1":71,"sym":71,"s c":71,"psy":71,"p t":71,"onf":71,"omf":71,"ols":71,"nol":71,"neb":71,"ne,":71,"nac":71,"måt":71,"m ö":71,"lbe":71,"i å":71,"hav":71,"glu":71,"fla":71,"dsa":71,"dol":71,"böc":71,".. ":71," ok":71,"y, ":70,"tif":70,"rn,":70,"rki":70,"pru":70,"pal":70,"oro":70,"nig":70,"ndu":70,"ma.":70,"llm":70,"lfä":70,"l j":70,"jek":70,"jde":70,"gol":70,"gd ":70,"g j":70,"enr":70,"ej ":70,"dsl":70,"ahl":70,".30":70," ås":70," tå":70,"öta":69,"vsk":69,"syk":69,"snö":69,"smu":69,"ses":69,"ryd":69,"orb":69,"oda":69,"nso":69,"iv.":69,"irr":69,"häm":69,"fie":69,"erå":69,"efe":69,"edo":69,"cie":69,"as,":69,"abe":69,"- 2":69," vu":69,"vun":68,"vst":68,"tbi":68,"rlu":68,"plo":68,"pit":68,"of ":68,"ob ":68,"o m":68,"nio":68,"mok":68,"m å":68,"kss":68,"kic":68,"ima":68,"hum":68,"geg":68,"ge.":68,"er:":68,"epa":68,"dus":68,"dfö":68,"ase":68,", \"":68,"\" v":68,"\" m":68,"öm ":67,"åge":67,"yn ":67,"vig":67,"tla":67,"sle":67,"skv":67,"see":67,"orl":67,"olt":67,"oen":67,"nkr":67,"mnd":67,"ikn":67,"es,":67,"ece":67,"döm":67,"d ö":67,"bad":67,":s ":67,"\" h":67," au":67," 30":67,"ögs":66,"én ":66,"äta":66,"vje":66,"vir":66,"urr":66,"to ":66,"sie":66,"ru ":66,"rg,":66,"ovj":66,"jup":66,"ici":66,"ibe":66,"gss":66,"fjä":66,"elä":66,": d":66,"197":66,".00":66,"ägs":65,"vna":65,"tås":65,"tsv":65,"pås":65,"pia":65,"p a":65,"osa":65,"mgå":65,"m \"":65,"jön":65,"iol":65,"id.":65,"grö":65,"gma":65,"ekl":65,"cir":65,"cep":65,"a: ":65,"0 -":65,"- a":65,"' m":65," 7 ":65,"åni":64,"ykt":64,"vek":64,"vas":64,"tgå":64,"she":64,"rbu":64,"rax":64,"onl":64,"ogs":64,"oga":64,"o a":64,"nöd":64,"löj":64,"k u":64,"igi":64,"fön":64,"fig":64,"ffä":64,"egå":64,"bur":64,"ado":64,"0. ":64,"\" n":64,"ömd":63,"tut":63,"tmä":63,"th ":63,"rdr":63,"pni":63,"olu":63,"olj":63,"ofe":63,"o s":63,"nko":63,"kig":63,"inj":63,"but":63,"bo ":63,"a 1":63,": s":63,"11 ":63,"\" f":63," vm":63,"äxt":62,"wed":62,"typ":62,"tne":62,"syd":62,"rsd":62,"rd.":62,"pec":62,"p f":62,"oml":62,"nöj":62,"nsd":62,"nfl":62,"mkr":62,"ljd":62,"idé":62,"hom":62,"gda":62,"es.":62,"egl":62,"efa":62," ad":62," 6 ":62,"öga":61,"yga":61,"uda":61,"tsp":61,"sil":61,"ry ":61,"rtj":61,"rha":61,"nfa":61,"lal":61,"kyd":61,"gsb":61,"frö":61,"dsb":61,"div":61,"d 1":61,"anh":61,"anc":61,"am.":61,"ach":61,"\" j":61," ån":61,"ör.":60,"uck":60,"u d":60,"tic":60,"ss.":60,"roe":60,"rbl":60,"pti":60,"nve":60,"nus":60,"lug":60,"lo ":60,"kst":60,"ipa":60,"ifi":60,"fti":60,"fss":60,"epr":60,"elo":60,"cin":60,"båt":60,"bul":60,"ax ":60,"00-":60," ul":60,"ät ":59,"vux":59,"ut,":59,"uga":59,"tug":59,"sör":59,"sål":59,"sbo":59,"ryn":59,"r 2":59,"på.":59,"nfo":59,"ndv":59,"jul":59,"iat":59,"gäs":59,"gil":59,"exa":59,"elg":59,"e '":59,"dsm":59,"bis":59,"abs":59,". å":59,"- 0":59,", c":59,", 1":59,"(19":59," äm":59," sh":59," es":59,"ymm":58,"xpe":58,"utm":58,"un ":58,"u a":58,"ppm":58,"pot":58,"ol ":58,"nva":58,"nov":58,"mde":58,"lmä":58,"ium":58,"ign":58,"i c":58,"glä":58,"fån":58,"eml":58,"ekv":58,"dål":58,"dle":58,"chi":58,"- k":58,"\" t":58,"öpa":57,"ynn":57,"v 1":57,"tha":57,"sts":57,"sem":57,"omg":57,"ns,":57,"not":57,"löm":57,"lt,":57,"kok":57,"jel":57,"häv":57,"hag":57,"gur":57,"gro":57,"ge,":57,"ffi":57,"elm":57,"0 0":57," 40":57,"ävd":56,"äft":56,"äda":56,"wal":56,"snä":56,"oän":56,"o o":56,"nsu":56,"nnl":56,"nlä":56,"mba":56,"k n":56,"it.":56,"is,":56,"g -":56,"eg ":56,"bid":56,"alj":56,". 2":56,"öro":55,"ägr":55,"vda":55,"us.":55,"tua":55,"smö":55,"skj":55,"roj":55,"ps ":55,"o i":55,"nob":55,"lkn":55,"lia":55,"lac":55,"ish":55,"ik,":55,"hil":55,"he ":55,"h ö":55,"emt":55,"ein":55,"ckr":55,"ck,":55,"anu":55,"\" i":55,"\" a":55," mj":55,"ökn":54,"öja":54,"yko":54,"väc":54,"ved":54,"u. ":54,"u e":54,"tål":54,"så,":54,"sef":54,"rd,":54,"rbj":54,"onn":54,"nbl":54,"itä":54,"isn":54,"igu":54,"h, ":54,"gåe":54,"ebe":54,"d \"":54,"bib":54,"aus":54," yn":54," ac":54," 9 ":54,"yge":53,"y s":53,"vål":53,"upe":53,"u g":53,"tmi":53,"så.":53,"spl":53,"sby":53,"rul":53,"pst":53,"pgi":53,"p p":53,"nri":53,"lap":53,"lak":53,"kid":53,"jni":53,"isd":53,"häs":53,"gse":53,"gle":53,"g: ":53,"flo":53,"fek":53,"eso":53,"eru":53,"dsp":53,"cit":53,"ce ":53,"by ":53,"bed":53,"be ":53,"azz":53,"aps":53,"alb":53,"abl":53,"196":53,"- i":53,"ädj":52,"via":52,"usk":52,"smo":52,"sgr":52,"rg.":52,"ptä":52,"oet":52,"löd":52,"läc":52,"lub":52,"llh":52,"lf ":52,"lex":52,"kif":52,"iri":52,"iog":52,"i 1":52,"hyr":52,"en?":52,"el,":52,"dsf":52,"dec":52,"con":52,"40 ":52,"0 p":52,", 2":52," ål":52," (s":52,"åk ":51,"äka":51,"viv":51,"urk":51,"tko":51,"teo":51,"sum":51,"s 1":51,"rvå":51,"rku":51,"rdh":51,"rbo":51,"pp,":51,"onb":51,"ofö":51,"odl":51,"lyf":51,"lm.":51,"lhe":51,"is.":51,"iod":51,"hn ":51,"hli":51,"has":51,"eff":51,"ebä":51,"dsv":51,"dgå":51,"agg":51,"5. ":51,"' a":51," ed":51,"öna":50,"ög ":50,"älf":50,"väd":50,"vse":50,"um.":50,"ul ":50,"tsf":50,"ts,":50,"tbo":50,"sa.":50,"rär":50,"rsm":50,"psa":50,"pph":50,"ldn":50,"kym":50,"jaz":50,"hri":50,"gsr":50,"fet":50,"dbe":50,"bom":50,"aly":50,"25 ":50,"14 ":50,"' h":50,"\" (":50," iv":50,"örg":49,"åt.":49,"äva":49,"ägn":49,"u p":49,"töv":49,"tsi":49,"sop":49,"sm ":49,"s -":49,"rkr":49,"rib":49,"rej":49,"rdf":49,"pfa":49,"oje":49,"når":49,"nty":49,"ngå":49,"nek":49,"nbe":49,"mle":49,"lv.":49,"lpa":49,"jd ":49,"itl":49,"igs":49,"iff":49,"hös":49,"gän":49,"gub":49,"evä":49,"chr":49,"cho":49,"ces":49,"bbt":49,"asp":49,"arh":49,"ael":49,". ö":49," ät":49," 21":49,"öne":48,"yke":48,"tja":48,"rrä":48,"pul":48,"pir":48,"peg":48,"n w":48,"llä":48,"jug":48,"jou":48,"jat":48,"ies":48,"ggs":48,"exi":48,"eut":48,"eho":48,"ean":48,"e? ":48,"dso":48,"dbo":48,"arc":48,"apl":48,"a (":48,"19.":48,"- l":48," cu":48," 60":48," 22":48,"ör,":47,"åts":47,"yse":47,"ugo":47,"tsm":47,"tjo":47,"sfa":47,"ryk":47,"r w":47,"r (":47,"prö":47,"poä":47,"omt":47,"oku":47,"ngn":47,"nch":47,"mda":47,"ma,":47,"kru":47,"iso":47,"h å":47,"gsv":47,"g? ":47,"fa ":47,"en:":47,"ems":47,"eet":47,"byt":47,"boh":47,"bb ":47,"alp":47,"alf":47,"acc":47,"199":47,"\" b":47," it":47," cr":47,"ögt":46,"ämd":46,"tåg":46,"tme":46,"tlä":46,"shu":46,"rsb":46,"rls":46,"plå":46,"nos":46,"mbi":46,"kut":46,"ipe":46,"g \"":46,"dvä":46,"dse":46,"dko":46,"dja":46,"dha":46,"api":46,"al.":46,"ain":46,") o":46,"' o":46," 70":46,"å 1":45,"urg":45,"töd":45,"täd":45,"tv ":45,"tma":45,"sbr":45,"rth":45,"rno":45,"rgr":45,"rdb":45,"påt":45,"onv":45,"omö":45,"ofs":45,"nia":45,"ngi":45,"mmo":45,"maj":45,"m c":45,"lre":45,"lef":45,"ld.":45,"l c":45,"khu":45,"hor":45,"gta":45,"gom":45,"fro":45,"fos":45,"eis":45,"efä":45,"ebu":45,"d -":45,"cup":45,"cel":45,"aha":45,"add":45,"ace":45,"- b":45," ia":45," 23":45,"åva":44,"å ö":44,"ägl":44,"va.":44,"us,":44,"tle":44,"tgi":44,"sup":44,"stm":44,"sa,":44,"rdo":44,"rac":44,"p e":44,"nku":44,"nha":44,"llg":44,"kle":44,"khe":44,"k j":44,"k g":44,"ivo":44,"inc":44,"him":44,"fäs":44,"ffr":44,"dum":44,"dog":44,"bod":44,"blu":44,"avv":44,"af ":44,"? m":44,"3 -":44,", ö":44," 2,":44,"åtm":43,"ys ":43,"yr ":43,"xtr":43,"uk ":43,"u l":43,"tss":43,"tap":43,"t! ":43,"säm":43,"sev":43,"sba":43,"röj":43,"rtä":43,"rhu":43,"pe ":43,"p d":43,"o å":43,"mp ":43,"llu":43,"lfö":43,"knä":43,"kju":43,"kak":43,"iär":43,"im ":43,"ias":43,"fjo":43,"ey ":43,"elh":43,"ekr":43,"ef ":43,"ed,":43,"ear":43,"dva":43,"dry":43,"can":43,"arp":43,"alr":43,"al,":43,"agd":43,"? j":43,"0 s":43,"' f":43," dn":43,"äkr":42,"yns":42,"yne":42,"yda":42,"y. ":42,"uff":42,"uer":42,"ttl":42,"tia":42,"ssä":42,"sfu":42,"sab":42,"rål":42,"räg":42,"rnv":42,"rhö":42,"rho":42,"pil":42,"ovä":42,"ot.":42,"nys":42,"måg":42,"mpr":42,"mik":42,"m '":42,"lfr":42,"lee":42,"kum":42,"jöl":42,"jol":42,"jes":42,"iml":42,"ica":42,"i \"":42,"gåv":42,"gsä":42,"ggd":42,"ff ":42,"dub":42,"deo":42,"def":42,"ap.":42,"afr":42,"? s":42,":- ":42,"200":42,"17 ":42,"' p":42,"' b":42," 24":42,"ömt":41,"öms":41,"åt,":41,"ådd":41,"wei":41,"vgö":41,"utk":41,"ur.":41,"uat":41,"tåt":41,"tät":41,"thu":41,"tgö":41,"ped":41,"out":41,"omn":41,"ohl":41,"myt":41,"msl":41,"mpi":41,"ltf":41,"lio":41,"kve":41,"ktn":41,"geo":41,"eol":41,"em,":41,"eku":41,"efr":41,"dic":41,"dge":41,"avd":41,"atl":41,"anm":41,"adr":41,"\" k":41," öd":41," ou":41," 1,":41,"ögr":40,"öds":40,"åmi":40,"vap":40,"uth":40,"sri":40,"sho":40,"se,":40,"rkv":40,"qui":40,"påm":40,"ppv":40,"plu":40,"onc":40,"omo":40,"nsm":40,"non":40,"ndt":40,"nak":40,"mjö":40,"mic":40,"mfo":40,"lur":40,"lso":40,"lj ":40,"ivl":40,"isc":40,"et?":40,"env":40,"dbr":40,"brå":40,"avb":40,"? -":40,"0:-":40,"0, ":40,"ödv":39,"å å":39,"å c":39,"äte":39,"yla":39,"win":39,"wil":39,"uve":39,"urv":39,"uis":39,"uge":39,"uce":39,"tlö":39,"tje":39,"tfu":39,"stk":39,"ryp":39,"rpa":39,"r y":39,"p h":39,"ovs":39,"onä":39,"nua":39,"ngb":39,"mju":39,"m 1":39,"k r":39,"hud":39,"h \"":39,"gef":39,"e w":39,"dok":39,"dep":39,"av.":39,"- p":39,", å":39,"' k":39," vr":39," od":39," 08":39,"öje":38,"ämf":38,"yli":38,"xt ":38,"v ä":38,"ums":38,"uin":38,"stb":38,"sfi":38,"ri.":38,"olf":38,"mår":38,"lök":38,"lum":38,"lsi":38,"lrä":38,"lif":38,"lft":38,"le,":38,"l ö":38,"ktö":38,"kne":38,"ivå":38,"isl":38,"hed":38,"g 1":38,"evo":38,"e 1":38,"dos":38,"d c":38,"cra":38,"cce":38,"avo":38,"900":38,"5 m":38,"190":38,"12.":38,"0 1":38,",5 ":38,"' d":38," 80":38," 25":38,"ärp":37,"älg":37,"ädg":37,"ysi":37,"ymp":37,"yg ":37,"y o":37,"uml":37,"ual":37,"tyn":37,"t y":37,"ssp":37,"ss,":37,"rub":37,"rro":37,"rmu":37,"qvi":37,"psk":37,"pau":37,"otb":37,"nyh":37,"nsä":37,"ngf":37,"myn":37,"mfa":37,"löv":37,"lyk":37,"lib":37,"lhö":37,"lei":37,"laf":37,"jas":37,"iv,":37,"ipl":37,"go ":37,"erp":37,"elp":37,"duc":37,"bön":37,"afe":37,"; d":37,"2, ":37,"100":37,"' v":37,"' i":37,"\" ä":37," äk":37," yo":37," og":37," oa":37," ai":37,"övd":36,"åvä":36,"åse":36,"ynt":36,"yhe":36,"v å":36,"usl":36,"ukh":36,"u n":36,"tva":36,"tsb":36,"tfo":36,"såv":36,"sås":36,"säs":36,"sk,":36,"sim":36,"sia":36,"rnd":36,"rlå":36,"pta":36,"pac":36,"oun":36,"oln":36,"nät":36,"ngk":36,"n y":36,"mol":36,"lvt":36,"luk":36,"lmö":36,"lge":36,"ksk":36,"kpa":36,"ja.":36,"ith":36,"it,":36,"ic ":36,"hei":36,"gi ":36,"g '":36,"fän":36,"flu":36,"epo":36,"dyr":36,"dyl":36,"bt ":36,"b, ":36,"aul":36,"asc":36,"amo":36,"? \"":36,"3 1":36,"18 ":36,"1. ":36,"08-":36,"0 å":36,") s":36,"' t":36,"\" l":36," cy":36,"ösn":35,"öma":35,"åln":35,"ål.":35,"äso":35,"äla":35,"yri":35,"ygt":35,"xan":35,"uva":35,"töt":35,"ty ":35,"tty":35,"ttv":35,"t (":35,"sif":35,"sci":35,"rtv":35,"rry":35,"rk.":35,"rih":35,"pär":35,"opt":35,"ony":35,"oko":35,"obs":35,"o p":35,"nu,":35,"nsc":35,"n 3":35,"mät":35,"mre":35,"lm,":35,"l -":35,"jos":35,"jda":35,"j. ":35,"ikl":35,"ikh":35,"iak":35,"hyl":35,"hul":35,"h. ":35,"gbo":35,"gag":35,"ft.":35,"flä":35,"et:":35,"ego":35,"edö":35,"edb":35,"e: ":35,"dek":35,"ddi":35,"d å":35,"anj":35,"agb":35,"a w":35,"7, ":35,"1 -":35,"0 t":35,". w":35,"- ä":35,"' e":35," å ":35," 90":35,"öjt":34,"åsa":34,"äsn":34,"äro":34,"vbr":34,"uke":34,"ssv":34,"sre":34,"sly":34,"rv ":34,"rnb":34,"påg":34,"pop":34,"ot,":34,"o h":34,"nts":34,"no ":34,"nju":34,"mäk":34,"mso":34,"lvä":34,"ke,":34,"k \"":34,"jke":34,"jka":34,"iös":34,"iko":34,"hat":34,"gio":34,"ggr":34,"ekä":34,"dun":34,"dga":34,"col":34,"byr":34,"bbl":34,"ay ":34,"amå":34,"amg":34,"aki":34,"2 -":34,"- u":34,"' l":34,"\" p":34," tö":34," ic":34,"öpe":33,"ödr":33,"åsk":33,"ån.":33,"ämr":33,"ysa":33,"yrå":33,"ymf":33,"väv":33,"urd":33,"uli":33,"tef":33,"t 2":33,"stf":33,"shi":33,"rnk":33,"rk,":33,"rfl":33,"pjä":33,"pig":33,"pie":33,"pfö":33,"omv":33,"okt":33,"oks":33,"näl":33,"nkn":33,"nci":33,"mvä":33,"mt.":33,"lsl":33,"lbo":33,"l \"":33,"kål":33,"ktt":33,"koh":33,"igå":33,"gsh":33,"fåg":33,"epi":33,"efö":33,"dof":33,"do ":33,"bec":33,"avt":33,"apo":33,"amv":33,"afs":33,"45 ":33,"/ 1":33," yr":33," oh":33," kj":33,"öld":32,"ö. ":32,"éer":32,"åkl":32,"ves":32,"ur,":32,"upa":32,"unc":32,"um,":32,"ttj":32,"tip":32,"t w":32,"roa":32,"riu":32,"orf":32,"okä":32,"nsf":32,"neg":32,"nbr":32,"lp ":32,"lol":32,"ksd":32,"knu":32,"kep":32,"iro":32,"ips":32,"ior":32,"ihe":32,"häf":32,"hs ":32,"flö":32,"etn":32,"edg":32,"e (":32,"dea":32,"dav":32,"chw":32,"beb":32,"ba ":32,"aln":32,": h":32,"9. ":32,"80 ":32,"60-":32,"50-":32,"2. ":32,"195":32,"15.":32," öm":32," gy":32,"öpt":31,"önt":31,"ågå":31,"å? ":31,"ype":31,"y m":31,"xis":31,"va,":31,"uxn":31,"uko":31,"tyv":31,"tv-":31,"tok":31,"sug":31,"suc":31,"stg":31,"sne":31,"smy":31,"sde":31,"s? ":31,"rud":31,"rgm":31,"oar":31,"nså":31,"nif":31,"ngö":31,"ndf":31,"mys":31,"ls.":31,"lpe":31,"krö":31,"jöd":31,"jäv":31,"jac":31,"ius":31,"isb":31,"ios":31,"i '":31,"hej":31,"gum":31,"fe ":31,"efu":31,"d '":31,"cyk":31,"ch,":31,"bl ":31,"bir":31,"b. ":31,"ash":31,"am,":31,"agr":31,": e":31,"60 ":31,"24 ":31,"194":31,"- 3":31," s ":31,"åd ":30,"ärh":30,"y t":30,"xen":30,"war":30,"vm-":30,"ulf":30,"ud.":30,"tba":30,"sep":30,"s- ":30,"rok":30,"rm.":30,"r! ":30,"pma":30,"pio":30,"phi":30,"pei":30,"nyg":30,"nyc":30,"nu.":30,"nny":30,"mek":30,"m: ":30,"lyr":30,"lpt":30,"lly":30,"lel":30,"ld,":30,"kys":30,"kug":30,"ktä":30,"kie":30,"ke.":30,"kdo":30,"joc":30,"id,":30,"hwe":30,"glo":30,"exu":30,"epe":30,"enä":30,"ea ":30,"då,":30,"dpe":30,"cip":30,"bea":30,"ap,":30,": m":30,"5 p":30,"193":30,"17.":30,"1, ":30,"00:":30,"- 4":30,"' n":30," ­ ":30," oe":30," gn":30,"åpe":29,"ärj":29,"y h":29,"vm ":29,"urm":29,"tz ":29,"tul":29,"säc":29,"sub":29,"spu":29,"sir":29,"seu":29,"sbi":29,"rs.":29,"rrå":29,"rkä":29,"ppi":29,"pa.":29,"omh":29,"o f":29,"o e":29,"nmä":29,"nma":29,"nem":29,"my ":29,"mse":29,"mbr":29,"löf":29,"låd":29,"lvk":29,"lv,":29,"lsv":29,"lsm":29,"lob":29,"lav":29,"l 2":29,"kny":29,"kgr":29,"jö ":29,"jäs":29,"ivä":29,"irl":29,"hoc":29,"gsi":29,"gn ":29,"ggt":29,"ggl":29,"fys":29,"fac":29,"emå":29,"elf":29,"eiz":29,"eby":29,"dén":29,"dug":29,"dta":29,"dsr":29,"dru":29,"dah":29,"cas":29,"aur":29,"atö":29,"alu":29,"akl":29,"afa":29,": v":29,": a":29,"986":29,"2 m":29,"19 ":29,"13.":29,"- g":29,", 5":29,", 3":29," t ":29," m ":29,"åkt":28,"älk":28,"ymt":28,"vta":28,"v \"":28,"toa":28,"tbe":28,"svu":28,"sk.":28,"sfr":28,"rså":28,"rah":28,"r 3":28,"psl":28,"ppd":28,"p k":28,"orp":28,"opu":28,"ofo":28,"obo":28,"o t":28,"nym":28,"nfr":28,"ndk":28,"nbo":28,"nag":28,"mum":28,"mn.":28,"ln.":28,"kök":28,"ktr":28,"kma":28,"kav":28,"ia,":28,"fto":28,"f. ":28,"emä":28,"elk":28,"edf":28,"eak":28,"aut":28,"apr":28,"aks":28,"abo":28,"a 3":28,"70-":28,"16 ":28,"1 s":28,"1 1":28,"0-å":28,"0 2":28,".0 ":28,", 6":28," wo":28," pä":28," pj":28," o ":28," nj":28," ep":28," (f":28," & ":28,"ån,":27,"äs ":27,"yto":27,"yld":27,"xpo":27,"xna":27,"xel":27,"was":27,"vkl":27,"utö":27,"udp":27,"tvu":27,"tir":27,"t; ":27,"stt":27,"sra":27,"snu":27,"sfo":27,"s: ":27,"rou":27,"rnt":27,"rau":27,"påv":27,"ppb":27,"pmä":27,"okl":27,"oes":27,"oba":27,"o l":27,"nro":27,"new":27,"n; ":27,"n 4":27,"mön":27,"mve":27,"msa":27,"mbl":27,"lvs":27,"ltm":27,"lsä":27,"lsp":27,"lha":27,"lfa":27,"ldt":27,"lau":27,"kyt":27,"kem":27,"juv":27,"jam":27,"itr":27,"ig?":27,"iam":27,"g c":27,"föt":27,"en)":27,"ehä":27,"då.":27,"dt ":27,"dsh":27,"dn ":27,"bso":27,"ar:":27,"abi":27,"86 ":27,"7 1":27,"6. ":27,"5, ":27,"4. ":27,"4 -":27,"3, ":27,"18.":27,"17,":27,"/ 2":27," py":27," p ":27,"ärb":26,"yrt":26,"ylt":26,"xor":26,"vra":26,"umo":26,"uma":26,"ulä":26,"tei":26,"tbr":26,"s w":26,"rsf":26,"ro.":26,"rfi":26,"rdl":26,"que":26,"pse":26,"pry":26,"opr":26,"opo":26,"opi":26,"oja":26,"oav":26,"o d":26,"nfe":26,"n) ":26,"miä":26,"lpl":26,"key":26,"js ":26,"irg":26,"ims":26,"idl":26,"iar":26,"h 1":26,"gry":26,"fts":26,"f f":26,"ep ":26,"enf":26,"drä":26,"dkä":26,"cki":26,"civ":26,"bje":26,"ak.":26,"5 -":26,"35 ":26,"22 ":26,"0 o":26,", 4":26,"! h":26," ug":26," jö":26," ik":26," (m":26," (d":26,"öm,":25,"åkr":25,"ågs":25,"äxe":25,"äni":25,"yvä":25,"yro":25,"ydi":25,"y f":25,"utd":25,"upt":25,"up ":25,"tub":25,"tpr":25,"sro":25,"saa":25,"rs,":25,"rby":25,"pus":25,"p n":25,"ood":25,"ohe":25,"oer":25,"nöt":25,"nåd":25,"ntä":25,"nks":25,"nbi":25,"mtl":25,"mte":25,"m? ":25,"lto":25,"lpr":25,"lou":25,"lgå":25,"kup":25,"klö":25,"kab":25,"isp":25,"ilf":25,"il.":25,"if ":25,"gui":25,"gsn":25,"gs.":25,"gie":25,"fi ":25,"eum":25,"er?":25,"epl":25,"eky":25,"egä":25,"dov":25,"dim":25,"dds":25,"d 2":25,"cor":25,"bäc":25,"aug":25,"ary":25,"anr":25,"anp":25,"akg":25,"air":25,": f":25,": 1":25,"9.3":25,"70 ":25,"500":25,"3. ":25,"192":25,"16.":25,"10.":25,"0- ":25,"\" g":25,"! d":25," ah":25," 35":25," 0.":25,"övs":24,"öpi":24,"öge":24,"åtg":24,"zan":24,"wit":24,"wes":24,"vät":24,"vie":24,"uxe":24,"ush":24,"ukd":24,"tsn":24,"tny":24,"tlo":24,"ted":24,"tau":24,"syf":24,"ssm":24,"sny":24,"si ":24,"sh ":24,"sgå":24,"sco":24,"sca":24,"rås":24,"rå ":24,"rtu":24,"rsu":24,"rmö":24,"rmt":24,"rfo":24,"rbä":24,"påp":24,"pa,":24,"oul":24,"osä":24,"osl":24,"orv":24,"oki":24,"obi":24,"o b":24,"ndy":24,"ndh":24,"n 5":24,"msp":24,"mir":24,"mac":24,"ly ":24,"luc":24,"ltr":24,"ltn":24,"lkä":24,"lkp":24,"lkm":24,"lga":24,"ley":24,"le.":24,"ksf":24,"kr ":24,"kov":24,"kje":24,"kik":24,"k -":24,"jät":24,"jea":24,"iki":24,"hug":24,"hak":24,"fir":24,"f, ":24,"etu":24,"esm":24,"enu":24,"ee ":24,"e 2":24,"did":24,"di ":24,"ddr":24,"dak":24,"com":24,"big":24,"avh":24,"anb":24,"alg":24,"aj ":24,"a! ":24,"987":24,"800":24,"20.":24,"- r":24,") f":24,"' r":24,"' g":24," 9.":24," 28":24," 27":24," 26":24," 1.":24," 0,":24,"öjn":23,"åne":23,"åls":23,"äxl":23,"äle":23,"yrs":23,"ypi":23,"y b":23,"ux ":23,"uks":23,"ubi":23,"u u":23,"tth":23,"sga":23,"saf":23,"s (":23,"rtl":23,"rpe":23,"r 4":23,"phö":23,"p u":23,"p b":23,"nuf":23,"mtr":23,"mie":23,"mi ":23,"mhu":23,"md ":23,"mbu":23,"lym":23,"lue":23,"lgr":23,"lab":23,"l: ":23,"l (":23,"l '":23,"köl":23,"ksl":23,"kfu":23,"kae":23,"ity":23,"ikr":23,"ie,":23,"ibu":23,"gso":23,"f s":23,"f p":23,"eun":23,"esg":23,"eps":23,"ebi":23,"döt":23,"dys":23,"bäd":23,"bi ":23,"bag":23,"ath":23,"aru":23,"aku":23,"ais":23,"agm":23,"afo":23,": i":23,"80-":23,"7. ":23,"6, ":23,"6 1":23,"5 å":23,"5 1":23,"16,":23,". 0":23,"- 8":23," sw":23," cd":23," ax":23," 3,":23," (e":23,"åve":22,"åki":22,"ynk":22,"yna":22,"ymn":22,"yer":22,"y p":22,"xer":22,"umb":22,"udg":22,"ube":22,"tso":22,"tfä":22,"sår":22,"stv":22,"stp":22,"ssö":22,"sgä":22,"sfä":22,"sfl":22,"sax":22,"sa:":22,"rza":22,"ruv":22,"rsj":22,"rr,":22,"ree":22,"på,":22,"pyr":22,"pep":22,"pdr":22,"p ä":22,"ow ":22,"onå":22,"onu":22,"omd":22,"ogg":22,"oc ":22,"nyb":22,"nkö":22,"nja":22,"nim":22,"n! ":22,"mgi":22,"me.":22,"m -":22,"löp":22,"lyd":22,"ljn":22,"lbu":22,"kjo":22,"k ö":22,"ia.":22,"håg":22,"gts":22,"gnu":22,"gka":22,"gir":22,"g 2":22,"g (":22,"er-":22,"enc":22,"eki":22,"edu":22,"eag":22,"dpu":22,"dlö":22,"dlä":22,"dev":22,"dd.":22,"cil":22,"chu":22,"cam":22,"bou":22,"b s":22,"an:":22,"? o":22,"? i":22,": j":22,"985":22,"8 1":22,"5 k":22,"30-":22,"0 d":22,"0 a":22,"\" -":22," 65":22," 31":22," (p":22,"önk":21,"ömn":21,"öft":21,"öer":21,"öd.":21,"ås.":21,"ånt":21,"ågt":21,"äl.":21,"yp ":21,"ymd":21,"ygd":21,"xak":21,"vju":21,"vio":21,"vgi":21,"vfö":21,"v ö":21,"tpl":21,"tof":21,"tka":21,"tgä":21,"syr":21,"shå":21,"sea":21,"sdi":21,"sav":21,"rvj":21,"rrt":21,"rgu":21,"rei":21,"rai":21,"pvä":21,"pak":21,"p v":21,"otr":21,"oth":21,"orä":21,"oho":21,"og.":21,"ofa":21,"odk":21,"nyf":21,"nsy":21,"nsb":21,"njö":21,"nai":21,"möd":21,"myg":21,"mt,":21,"mko":21,"lmb":21,"llå":21,"ksp":21,"kim":21,"iru":21,"irm":21,"inä":21,"ikv":21,"hac":21,"gsg":21,"gha":21,"fav":21,"f l":21,"evs":21,"evl":21,"eon":21,"elö":21,"ek.":21,"eid":21,"efl":21,"deg":21,"cem":21,"blö":21,"55 ":21,"2 0":21,"180":21,"14.":21,"0 f":21,".45":21,"-ma":21,"-gu":21,"\" u":21," zi":21," i.":21," f ":21,"övl":20,"öss":20,"ön.":20,"ölk":20,"åns":20,"äpn":20,"än,":20,"ägd":20,"zar":20,"z, ":20,"ymb":20,"y l":20,"xla":20,"x. ":20,"vul":20,"vle":20,"vbi":20,"uls":20,"udn":20,"tsg":20,"tkr":20,"tai":20,"sth":20,"ssb":20,"rr.":20,"psä":20,"p 1":20,"oui":20,"op.":20,"onj":20,"ois":20,"ogn":20,"ods":20,"odo":20,"nyl":20,"nhö":20,"ngv":20,"ngm":20,"mö ":20,"myr":20,"mur":20,"msv":20,"lén":20,"lvb":20,"lkl":20,"ljs":20,"leb":20,"l å":20,"k: ":20,"jtn":20,"jej":20,"ivr":20,"ifo":20,"idg":20,"hls":20,"ha,":20,"h '":20,"gås":20,"gpl":20,"gos":20,"ght":20,"ged":20,"ft,":20,"f h":20,"ew ":20,"etc":20,"eif":20,"ebb":20,"e y":20,"dy ":20,"dma":20,"axe":20,"arz":20,"a:s":20,"? v":20,"? n":20,"? e":20,": t":20,"85 ":20,"300":20,"23 ":20,"2 k":20,"191":20,"18,":20,"1 f":20,"0 b":20,"0 5":20,".50":20,"- 7":20,"- 5":20,",2 ":20,"(so":20,"' u":20,"' j":20,"! j":20," ze":20,"ösh":19,"öse":19,"ö, ":19,"ö s":19,"ö o":19,"åtf":19,"årv":19,"åel":19,"äxa":19,"äts":19,"äds":19,"ynl":19,"ym ":19,"y k":19,"vsi":19,"usn":19,"umt":19,"tpa":19,"thi":19,"sus":19,"sue":19,"ssf":19,"sru":19,"sno":19,"sbl":19,"s y":19,"rtg":19,"rnu":19,"rfä":19,"rch":19,"rce":19,"pfo":19,"ops":19,"oph":19,"oin":19,"og,":19,"o k":19,"o g":19,"nå ":19,"nsr":19,"ng:":19,"ndp":19,"n),":19,"mut":19,"mug":19,"mto":19,"mob":19,"lvå":19,"lvm":19,"lvf":19,"liu":19,"lbr":19,"lai":19,"kba":19,"jöe":19,"je,":19,"itz":19,"ip ":19,"imu":19,"icr":19,"i w":19,"hes":19,"gto":19,"ggi":19,"gby":19,"fog":19,"evn":19,"enj":19,"en;":19,"en-":19,"elå":19,"ejd":19,"eas":19,"dyk":19,"dba":19,"cou":19,"c, ":19,"blä":19,"bab":19,"aos":19,"an?":19,"an-":19,"aco":19,"ab ":19,"8 m":19,"600":19,"6 s":19,"5 0":19,"21 ":19,"2.0":19,"2 s":19,"1 m":19,"-19":19,",4 ":19," 75":19," 29":19,"örö":18,"åti":18,"åso":18,"åsi":18,"ås,":18,"äsb":18,"zis":18,"ytm":18,"yor":18,"yme":18,"ygp":18,"xti":18,"xpr":18,"vå.":18,"vre":18,"vok":18,"v 2":18,"utp":18,"urh":18,"udo":18,"u r":18,"tsu":18,"t) ":18,"ssh":18,"sou":18,"röl":18,"rsc":18,"rpl":18,"rnä":18,"rny":18,"rmé":18,"rmä":18,"rhi":18,"rfr":18,"put":18,"pes":18,"ous":18,"orh":18,"ok.":18,"ok,":18,"näc":18,"npr":18,"nhå":18,"nhä":18,"neu":18,"msä":18,"mog":18,"mmy":18,"lvo":18,"lro":18,"lgä":18,"lgo":18,"lah":18,"kår":18,"kyn":18,"k 1":18,"jub":18,"jt ":18,"jov":18,"jo,":18,"jev":18,"jef":18,"je.":18,"ixt":18,"inh":18,"il,":18,"ihå":18,"ied":18,"gym":18,"gtr":18,"gno":18,"gba":18,"ftn":18,"ftf":18,"ffs":18,"f i":18,"erc":18,"eje":18,"eir":18,"eim":18,"du,":18,"djä":18,"dhe":18,"ddn":18,"daf":18,"d: ":18,"d y":18,"ckf":18,"byn":18,"bs ":18,"beu":18,"bem":18,"axi":18,"avn":18,"aux":18,"aja":18,"abu":18,"aba":18,"a y":18,"a 2":18,"? a":18,": p":18,": -":18,"9 m":18,"9 1":18,"83 ":18,"700":18,"4 s":18,"4 p":18,"1) ":18,"1 6":18,"0 l":18,"-fi":18,"-er":18,"' ä":18,"! m":18,"! -":18," k ":18," g ":18," fn":18," ej":18," dv":18," 45":18," 2.":18,"öp ":17,"önh":17,"öme":17,"öd,":17,"å 2":17,"å \"":17,"äsk":17,"är:":17,"äg.":17,"zen":17,"ygs":17,"yan":17,"xpa":17,"xa ":17,"woo":17,"wer":17,"vrä":17,"v c":17,"v '":17,"uru":17,"urb":17,"ugu":17,"ttf":17,"tos":17,"tob":17,"thå":17,"tde":17,"tby":17,"srä":17,"sic":17,"seb":17,"rö ":17,"ré ":17,"rtn":17,"rtb":17,"rrl":17,"rpo":17,"rnl":17,"rml":17,"rkö":17,"ri,":17,"r; ":17,"r 7":17,"pip":17,"pea":17,"osy":17,"on)":17,"odn":17,"obj":17,"oal":17,"o r":17,"näv":17,"nvå":17,"nth":17,"nsg":17,"npu":17,"niu":17,"nip":17,"ngh":17,"nav":17,"n /":17,"måd":17,"msi":17,"lpi":17,"lix":17,"leo":17,"lax":17,"ktm":17,"ksb":17,"koj":17,"kod":17,"kao":17,"j k":17,"ipi":17,"imb":17,"ifa":17,"ht ":17,"gös":17,"gva":17,"gik":17,"fs ":17,"f m":17,"f b":17,"et;":17,"esä":17,"eja":17,"ej.":17,"edt":17,"då?":17,"däm":17,"dqv":17,"dip":17,"dfl":17,"dfa":17,"cre":17,"co ":17,"ch.":17,"c. ":17,"byx":17,"bee":17,"b h":17,"atj":17,"aik":17,"aar":17,"90 ":17,"8-7":17,"75 ":17,"7 s":17,"4 1":17,"3 m":17,"28 ":17,"22.":17,"19,":17,"05 ":17,"/ s":17,". (":17,"-se":17,"- 9":17,"- 6":17,", w":17,") m":17,"' c":17,"! \"":17," zo":17," mr":17," ji":17," d ":17," b ":17," (t":17,"övn":16,"öm.":16,"öbe":16,"é. ":16,"ål,":16,"änl":16,"än.":16,"äd ":16,"yti":16,"ylv":16,"yfi":16,"xue":16,"väm":16,"vvi":16,"vsm":16,"vlo":16,"vgå":16,"uso":16,"ur?":16,"ue ":16,"ud,":16,"ubr":16,"tuk":16,"tté":16,"thr":16,"t 5":16,"söt":16,"so ":16,"snå":16,"shä":16,"ryl":16,"rs-":16,"rgl":16,"rdö":16,"ray":16,"rae":16,"qua":16,"pål":16,"ptr":16,"otv":16,"os.":16,"oru":16,"onp":16,"ogå":16,"oan":16,"o v":16,"nue":16,"ntv":16,"ntb":16,"nsö":16,"nsn":16,"nru":16,"npa":16,"nlö":16,"nid":16,"nho":16,"ng)":16,"nev":16,"na-":16,"n 7":16,"mös":16,"mög":16,"mva":16,"mns":16,"lvl":16,"lup":16,"lri":16,"lo.":16,"lk.":16,"lfi":16,"l? ":16,"kån":16,"ktf":16,"ko ":16,"kmu":16,"kij":16,"kha":16,"jum":16,"j t":16,"isr":16,"imo":16,"ilh":16,"ihj":16,"ie.":16,"idu":16,"ico":16,"iba":16,"hl ":16,"hie":16,"gsd":16,"giö":16,"ggo":16,"fry":16,"fok":16,"esb":16,"elu":16,"ejä":16,"eel":16,"eed":16,"ech":16,"e) ":16,"e! ":16,"dsj":16,"d w":16,"d (":16,"chö":16,"chs":16,"ced":16,"cat":16,"bys":16,"buk":16,"bst":16,"bly":16,"bbi":16,"b o":16,"avk":16,"aud":16,"atk":16,"ail":16,"adj":16,"aab":16,"a) ":16,"; e":16,"7 å":16,"7 p":16,"4, ":16,"38 ":16,"32 ":16,"30.":16,"29 ":16,"111":16,"1 7":16,"0.0":16,"0 n":16,"0 i":16,". y":16,"-pr":16,"-ba":16,",8 ":16,",1 ":16,", 7":16,", '":16,") i":16,") h":16,"\" r":16," öl":16," åh":16," ud":16," qu":16," ph":16," ii":16," 5.":16," 47":16," 4,":16," 38":16," 37":16," (v":16,"ödl":15,"ér ":15,"én,":15,"ågl":15,"ätr":15,"ägt":15,"äby":15,"zon":15,"zer":15,"z o":15,"ypt":15,"you":15,"yki":15,"yka":15,"y g":15,"y d":15,"xto":15,"x f":15,"wan":15,"vvä":15,"vsä":15,"vsp":15,"vo ":15,"vlä":15,"vep":15,"ulv":15,"ulj":15,"ues":15,"udb":15,"ucc":15,"töl":15,"tt?":15,"tsj":15,"tev":15,"tee":15,"tbu":15,"spö":15,"sk-":15,"shö":15,"sbu":15,"sai":15,"sac":15,"s) ":15,"rög":15,"rsy":15,"rpr":15,"rjo":15,"riä":15,"r 5":15,"påf":15,"peu":15,"otå":15,"otu":15,"osc":15,"od.":15,"oak":15,"o '":15,"nyk":15,"npå":15,"nod":15,"ndq":15,"nbö":15,"na?":15,"na:":15,"mr ":15,"map":15,"lyn":15,"lud":15,"lsn":15,"lps":15,"lmo":15,"ll-":15,"li.":15,"lgi":15,"käg":15,"ky ":15,"ksi":15,"krå":15,"kof":15,"kmo":15,"k '":15,"jöb":15,"jsa":15,"irv":15,"ilv":15,"ibr":15,"hai":15,"göm":15,"gsu":15,"gnt":15,"gns":15,"gev":15,"ga:":15,"g! ":15,"fur":15,"etä":15,"ery":15,"er)":15,"elj":15,"eil":15,"döp":15,"dée":15,"dé ":15,"dyn":15,"dho":15,"dgu":15,"dby":15,"d 3":15,"bäg":15,"byl":15,"bya":15,"boy":15,"boe":15,"bmw":15,"azi":15,"avf":15,"av,":15,"aqu":15,"apt":15,"ak,":15,"aid":15,"agh":15,"aes":15,"? f":15,": b":15,": '":15,"960":15,"90-":15,"82 ":15,"8 f":15,"77 ":15,"68 ":15,"5 o":15,"400":15,"40-":15,"31 ":15,"3 s":15,"3 0":15,"27 ":15,"26 ":15,"21.":15,"2) ":15,"120":15,"1 2":15,"1 0":15,"0 r":15,".15":15,"-ti":15,"-le":15,",9 ":15,",6 ":15," äp":15," ss":15," e ":15," cm":15," bm":15," 71":15," 7,":15," 07":15," (o":15," (h":15," (2":15,"öks":14,"öar":14,"ålk":14,"åkn":14,"åa ":14,"ädr":14,"zz ":14,"yrd":14,"ynp":14,"yle":14,"yen":14,"ye ":14,"ybe":14,"y i":14,"y a":14,"xta":14,"xpl":14,"x s":14,"wag":14,"w y":14,"våa":14,"vve":14,"vss":14,"vsn":14,"vpk":14,"von":14,"vgj":14,"vbo":14,"vax":14,"usb":14,"urp":14,"uit":14,"uen":14,"täb":14,"tsh":14,"tou":14,"tmo":14,"tkl":14,"tge":14,"tax":14,"t 6":14,"swa":14,"sot":14,"råv":14,"rue":14,"ruc":14,"rsn":14,"rpå":14,"rms":14,"reo":14,"r) ":14,"pur":14,"ppå":14,"ply":14,"osm":14,"ool":14,"onr":14,"omu":14,"ol.":14,"ol,":14,"okk":14,"ody":14,"o: ":14,"näg":14,"nrä":14,"nr ":14,"nqu":14,"nof":14,"nnr":14,"njo":14,"nbu":14,"mnt":14,"mlä":14,"mhå":14,"lmi":14,"lbi":14,"kud":14,"ktb":14,"kka":14,"kfö":14,"keg":14,"keb":14,"jös":14,"jd.":14,"j f":14,"isu":14,"ilb":14,"iev":14,"ie-":14,"ics":14,"ibi":14,"hyg":14,"hns":14,"hir":14,"hic":14,"hau":14,"guv":14,"gue":14,"gmä":14,"gim":14,"gfr":14,"g) ":14,"g 3":14,"f o":14,"f k":14,"ez ":14,"etv":14,"esc":14,"eph":14,"enm":14,"en!":14,"ely":14,"eer":14,"e 4":14,"e 3":14,"döl":14,"dur":14,"dsg":14,"dsc":14,"ds.":14,"dop":14,"dne":14,"dil":14,"dex":14,"ded":14,"de?":14,"dbl":14,"d? ":14,"d 4":14,"cti":14,"ckv":14,"bsu":14,"boo":14,"bb.":14,"avä":14,"amu":14,"akr":14,"ajs":14,"ag:":14,"afé":14,"adk":14,"a 5":14,"? t":14,"? b":14,"; s":14,"983":14,"9, ":14,"87 ":14,"5 a":14,"5 /":14,"4 m":14,"39 ":14,"3 2":14,"2 3":14,"2 2":14,".20":14,"-ol":14,"-br":14,"- c":14,",0 ":14,", 8":14,") p":14,"' '":14," v ":14," mc":14," 64":14," 39":14," 32":14," (l":14," (c":14,"ösk":13,"ök.":13,"ögl":13,"ödi":13,"én.":13,"årl":13,"ånl":13,"ålv":13,"åer":13,"yxo":13,"ysn":13,"ypa":13,"ynä":13,"yni":13,"yn.":13,"ygn":13,"ydn":13,"y j":13,"xua":13,"x, ":13,"x e":13,"vmo":13,"vfa":13,"umg":13,"ukv":13,"uk.":13,"udr":13,"ttö":13,"tmu":13,"tgj":13,"tfl":13,"t 4":13,"t 3":13,"söm":13,"sé ":13,"swe":13,"ssy":13,"sdr":13,"s 2":13,"rsg":13,"roi":13,"rnf":13,"rhä":13,"päl":13,"pva":13,"psd":13,"pag":13,"p l":13,"oxa":13,"ovo":13,"oup":13,"otä":13,"osp":13,"os,":13,"orö":13,"op,":13,"onh":13,"omä":13,"olg":13,"odr":13,"näp":13,"nye":13,"nn,":13,"nlu":13,"nfi":13,"ney":13,"nef":13,"ndm":13,"nck":13,"n:s":13,"n 8":13,"mér":13,"mss":13,"msb":13,"mpn":13,"mka":13,"mby":13,"may":13,"m-s":13,"lsf":13,"lmé":13,"lkr":13,"leu":13,"ldk":13,"lae":13,"l 3":13,"kåp":13,"kvå":13,"ktl":13,"ksä":13,"kno":13,"kir":13,"k c":13,"jua":13,"joa":13,"j s":13,"j o":13,"ito":13,"isö":13,"ilé":13,"ife":13,"hle":13,"h w":13,"gäv":13,"gyn":13,"gyl":13,"gs-":13,"gn.":13,"gme":13,"gaf":13,"g w":13,"fuk":13,"ftv":13,"f r":13,"f a":13,"evd":13,"eud":13,"esh":13,"eo ":13,"enp":13,"dö ":13,"dyg":13,"dtr":13,"dte":13,"dsn":13,"dka":13,"dd,":13,"ckk":13,"cht":13,"cec":13,"cci":13,"bäl":13,"by.":13,"bse":13,"bb,":13,"b i":13,"avr":13,"asm":13,"arö":13,"ar?":13,"amk":13,"ajo":13,"ahe":13,"aci":13,"a 8":13,"? l":13,"? k":13,"977":13,"9.0":13,"84 ":13,"8. ":13,"8 p":13,"76 ":13,"6 -":13,"59 ":13,"5.0":13,"5 t":13,"43 ":13,"4 d":13,"20-":13,"2 o":13,"150":13,"10,":13,"0 u":13,"0 h":13,"0 g":13,"0 7":13,"0 3":13,"-ko":13,"- å":13,") b":13,"(fö":13,"(el":13," vp":13," um":13," km":13," aq":13," 68":13," 41":13," 36":13," 34":13," * ":13,"ön,":12,"öla":12,"ålt":12,"åko":12,"åk.":12,"åk,":12,"ävs":12,"äsm":12,"änh":12,"äne":12,"ägb":12,"ypo":12,"ykl":12,"yar":12,"y w":12,"y v":12,"y e":12,"y c":12,"y -":12,"xli":12,"x p":12,"wor":12,"wis":12,"wid":12,"wic":12,"vva":12,"vsf":12,"vrå":12,"vkr":12,"vka":12,"usc":12,"urf":12,"umf":12,"ulo":12,"ulg":12,"uch":12,"uas":12,"u å":12,"ttg":12,"tsr":12,"thä":12,"tfi":12,"tep":12,"tbl":12,"söv":12,"sö ":12,"såk":12,"std":12,"sos":12,"sok":12,"sm,":12,"sks":12,"scu":12,"rén":12,"rtk":12,"rsh":12,"roo":12,"ro,":12,"rnp":12,"rmn":12,"rl-":12,"rgä":12,"rgn":12,"rfe":12,"rdv":12,"rdk":12,"ra?":12,"pån":12,"pto":12,"plä":12,"pho":12,"otf":12,"osé":12,"orc":12,"ook":12,"okh":12,"ogu":12,"odt":12,"oad":12,"oa ":12,"o u":12,"o n":12,"nål":12,"nuv":12,"nsh":12,"nry":12,"nra":12,"npl":12,"nk,":12,"nbj":12,"naz":12,"n).":12,"n z":12,"n 6":12,"mou":12,"mn,":12,"mix":12,"mif":12,"mia":12,"lvr":12,"ltj":12,"lth":12,"llö":12,"llp":12,"lk,":12,"ljt":12,"lfe":12,"kty":12,"ksm":12,"ksh":12,"kku":12,"kfo":12,"kfi":12,"kaj":12,"jöm":12,"jec":12,"jeb":12,"jap":12,"jah":12,"ivk":12,"ivb":12,"itn":12,"ily":12,"igr":12,"hyp":12,"hma":12,"hlb":12,"hju":12,"hje":12,"gö ":12,"gvi":12,"gti":12,"gog":12,"gof":12,"gi.":12,"gd.":12,"gaa":12,"fög":12,"f j":12,"f e":12,"ewi":12,"evt":12,"esd":12,"erj":12,"er!":12,"eog":12,"ekf":12,"ek,":12,"ejk":12,"egy":12,"eg.":12,"eam":12,"dvs":12,"dsd":12,"ds-":12,"dox":12,"ddo":12,"cur":12,"cli":12,"ckm":12,"cio":12,"cig":12,"bän":12,"by,":12,"bob":12,"bk ":12,"bif":12,"b k":12,"aty":12,"alö":12,"aje":12,"ait":12,"agu":12,"aby":12,"a; ":12,"a-c":12,"a 4":12,": l":12,"970":12,"95 ":12,"8, ":12,"8 å":12,"8 /":12,"72 ":12,"7.0":12,"6 m":12,"6 f":12,"5) ":12,"5 d":12,"4) ":12,"4 3":12,"3 p":12,"20,":12,"2 p":12,"2 h":12,"170":12,"1 3":12,"001":12,"0 e":12,".55":12,".10":12,"-vi":12,"-st":12,"-lo":12,") a":12,") 1":12,"(de":12,"' -":12," åb":12," za":12," pk":12," ei":12," 87":12," 6.":12," 54":12," 48":12," 44":12," 33":12," 2-":12," 1)":12," \")":12,"öni":11,"ögn":11,"ödo":11,"ö i":11,"é o":11,"é m":11,"åbe":11,"å -":11,"äsv":11,"ämj":11,"ämb":11,"älb":11,"zze":11,"zig":11,"ygr":11,"xit":11,"xho":11,"xar":11,"wat":11,"wah":11,"vös":11,"väp":11,"vsa":11,"vha":11,"vea":11,"vd ":11,"v: ":11,"v 6":11,"usg":11,"ulp":11,"ukl":11,"udt":11,"tén":11,"tå.":11,"täk":11,"tv:":11,"tsc":11,"tl ":11,"tku":11,"tiö":11,"ths":11,"tga":11,"teu":11,"squ":11,"sod":11,"sgi":11,"sdo":11,"s-g":11,"råa":11,"rvö":11,"rui":11,"rp ":11,"roh":11,"rnh":11,"rl.":11,"r).":11,"ptu":11,"psi":11,"ppk":11,"pok":11,"pgö":11,"pga":11,"pfi":11,"pee":11,"pba":11,"p g":11,"p 2":11,"p \"":11,"oza":11,"ov,":11,"ou ":11,"om?":11,"nör":11,"nér":11,"nyu":11,"nui":11,"nub":11,"nt:":11,"nop":11,"nn.":11,"nhu":11,"nep":11,"nea":11,"nau":11,"mén":11,"mpt":11,"m-t":11,"m (":11,"lvu":11,"lsb":11,"ls,":11,"low":11,"lne":11,"ln,":11,"lmu":11,"lku":11,"lks":11,"lki":11,"lkh":11,"ljé":11,"li,":11,"lew":11,"lea":11,"ldo":11,"ldh":11,"käf":11,"ksv":11,"kr.":11,"kko":11,"ki ":11,"ke-":11,"k? ":11,"k- ":11,"jöv":11,"jo ":11,"jim":11,"jep":11,"jdp":11,"jav":11,"jal":11,"ize":11,"iza":11,"imt":11,"imr":11,"ikg":11,"ii ":11,"igd":11,"ict":11,"i 5":11,"hee":11,"hea":11,"h y":11,"h 2":11,"gig":11,"gia":11,"gg,":11,"gfö":11,"gfo":11,"gdr":11,"gbe":11,"gab":11,"g).":11,"ffl":11,"ev.":11,"et!":11,"erw":11,"enq":11,"elr":11,"ejo":11,"eic":11,"eav":11,"e-l":11,"dts":11,"dsä":11,"dsu":11,"dn:":11,"diu":11,"dfr":11,"de:":11,"d 5":11,"cot":11,"cm ":11,"cab":11,"böl":11,"bum":11,"bei":11,"bau":11,"baj":11,"aye":11,"axh":11,"aun":11,"auk":11,"asä":11,"amö":11,"adu":11,"adl":11,"a-b":11,"; h":11,": u":11,": r":11,": n":11,"980":11,"950":11,"9 2":11,"8.0":11,"8 0":11,"7 0":11,"65 ":11,"56 ":11,"5-å":11,"5 v":11,"5 s":11,"5 f":11,"5 2":11,"41 ":11,"4.0":11,"4 f":11,"3) ":11,"3 o":11,"23.":11,"2 f":11,"2 a":11,"125":11,"11.":11,"1 p":11,"1 k":11,"1 b":11,"1 5":11,"0) ":11,"0 c":11,"0 8":11,"0 4":11,".40":11,".) ":11,"-åk":11,"-tr":11,"-sp":11,"-sa":11,"-co":11,"-an":11,") ä":11,") t":11," yl":11," t-":11," sq":11," ns":11," nr":11," kå":11," ec":11," 95":11," 7.":11," 6,":11," 42":11," 3.":11," (i":11,"ös.":10,"önl":10,"öml":10,"öl ":10,"éns":10,"åtr":10,"åds":10,"å 6":10,"å 3":10,"äxo":10,"äru":10,"äm ":10,"yut":10,"yt ":10,"yd ":10,"ybo":10,"xam":10,"x m":10,"x i":10,"x b":10,"x a":10,"wig":10,"way":10,"vsv":10,"vro":10,"vga":10,"v-s":10,"uvo":10,"ul.":10,"ul,":10,"uil":10,"uhr":10,"ugi":10,"u j":10,"töm":10,"tym":10,"tye":10,"tv,":10,"tup":10,"tré":10,"tpe":10,"to:":10,"tno":10,"tlå":10,"th.":10,"tgr":10,"tdr":10,"tdo":10,"tah":10,"ta-":10,"t- ":10,"t 7":10,"syl":10,"sv ":10,"sså":10,"ss?":10,"srå":10,"sm.":10,"sja":10,"sbä":10,"sau":10,"sa-":10,"s:t":10,"s-e":10,"röp":10,"rår":10,"råe":10,"rwa":10,"rrö":10,"rrk":10,"rps":10,"rlj":10,"rky":10,"rgö":10,"rgg":10,"rgf":10,"r..":10,"r 9":10,"r 8":10,"pök":10,"påk":10,"pkk":10,"pic":10,"phe":10,"pfy":10,"peh":10,"pby":10,"p -":10,"oår":10,"oxi":10,"oty":10,"oon":10,"onö":10,"od,":10,"ob,":10,"o c":10,"o -":10,"nön":10,"nö ":10,"nå,":10,"nyp":10,"nun":10,"nok":10,"nkb":10,"ni,":10,"ng?":10,"ng-":10,"nfu":10,"ne?":10,"n 9":10,"msf":10,"mrö":10,"mpu":10,"mps":10,"mp,":10,"mo ":10,"mgr":10,"meu":10,"mec":10,"mdö":10,"max":10,"m w":10,"lsy":10,"ls-":10,"lru":10,"lp.":10,"loo":10,"lj,":10,"leå":10,"lej":10,"kåt":10,"kse":10,"kih":10,"khö":10,"kee":10,"kds":10,"kbo":10,"jög":10,"jö.":10,"jok":10,"itö":10,"itv":10,"irt":10,"io.":10,"io,":10,"inp":10,"ilu":10,"ikk":10,"ikf":10,"ig:":10,"ifu":10,"ifk":10,"iem":10,"idy":10,"i y":10,"hån":10,"häp":10,"hre":10,"hae":10,"ha.":10,"gyp":10,"gve":10,"gt-":10,"gs,":10,"gi,":10,"ggö":10,"gfa":10,"gei":10,"gbi":10,"fsa":10,"fk ":10,"f d":10,"etz":10,"etl":10,"esy":10,"el-":10,"ekp":10,"ecu":10,"eau":10,"dua":10,"ds,":10,"dif":10,"dhä":10,"cus":10,"cto":10,"cos":10,"cca":10,"byb":10,"bsb":10,"box":10,"bog":10,"boc":10,"bam":10,"axo":10,"axl":10,"awa":10,"asy":10,"akå":10,"adv":10,"aas":10,"a z":10,"a 6":10,"? g":10,"; m":10,":e ":10,": o":10,": k":10,": g":10,"981":10,"98 ":10,"979":10,"9 s":10,"9 3":10,"85.":10,"79 ":10,"71 ":10,"7) ":10,"69 ":10,"66 ":10,"64 ":10,"61 ":10,"6.0":10,"6 p":10,"48 ":10,"47 ":10,"42 ":10,"4 å":10,"4 k":10,"37 ":10,"201":10,"2.3":10,"2 å":10,"2 v":10,"2 l":10,"2 9":10,"185":10,"1.0":10,"1,5":10,"1 å":10,"1 j":10,"1 4":10,"06 ":10,"03 ":10,"0 v":10,"0 j":10,"/ t":10,".25":10,".05":10,"-vm":10,"-te":10,"-mo":10,"-ka":10,"- \"":10,",3 ":10,") k":10,"(me":10,"\" c":10,"! s":10," à ":10," wr":10," ts":10," s:":10," kd":10," j ":10," hv":10," ea":10," 99":10," 85":10," 8.":10," 4.":10," (b":10};
	var refLen = 61204.676251;
	
	var trigrams = {};
	if(text.length < 3) {
	    return false;
	} else {
	    for(var c = 2; c < text.length; c++) {
		var tri = text.substring(c - 2, c+1).toLowerCase();
		if(trigrams.hasOwnProperty(tri)) {
		    trigrams[tri] += 1;
		} else {
		    trigrams[tri] = 1;
		}
	    }
	}
	var tot = text.length - 2;
	
	var sum = 0;
	var l = 0;
	for(var t in trigrams) {
	    if(trigrams.hasOwnProperty(t)) {
		l += trigrams[t] * trigrams[t];
		if(refs.hasOwnProperty(t)) {
		    sum += trigrams[t] * refs[t];
		}
	    }
	}
	l = Math.sqrt(l);
	var res = sum / l / refLen;
	
	if(res < 0.3) {
	    return false;
	} else {
	    return true;
	}
    }    

    // ---------------------------------------------------------------------------------
    // function pushCorrectionToPage(granskaSentences, sIdx, eIdx, chosenSuggestion, elemIdx)
    // ---------------------------------------------------------------------------------
    // When a suggested correction from the grammar checker is clicked,
    // update the original text in accordance with the suggestion. 
    // ---------------------------------------------------------------------------------
    function pushCorrectionToPage(granskaSentences, sIdx, eIdx, chosenSuggestion, elemIdx) {
	// Figure out where in the original text the suggestion should be
	// inserted.  Match tokens to the text content (the whitespace
	// etc. is likely different in the grammar checking results).
	var lastSpanStart = 0;
	var lastTokenEnd = -1;
	var lastTokenStart = -1;
	var failed = false;

	var newText = "";
	
	if(elemIdx < seenTexts.length) {
    	    var orgText = seenTexts[elemIdx].text;
	    
    	    var p = 0;
    	    for(var s = 0; s < sIdx; s++) {
		var tokens = granskaSentences[s][1];
		
    		for (var t = 0; t < tokens.length; t++) {
    		    var p2 = orgText.indexOf(tokens[t][0], p);
    		    if (p2 >= 0) {
    			p = p2 + tokens[t][0].length;
    			lastTokenStart = p2;
    			lastTokenEnd = p;
    		    } else {
    			failed = true;
    			console.log("WARNING: Cannot find location in text to use the suggestion.");
    			break;
    		    }
    		}
    	    }
	    
	    // Go through the text, save the text parts not related to the
	    // suggested correction, and also replace the parts related to
	    // the suggestion with the new text.
	    
    	    var spansToKeep = [];
    	    var insideMarking = false;
	    
    	    var tokens = granskaSentences[sIdx][1];
    	    var err = granskaSentences[sIdx][2][eIdx];

    	    for (var t = 0; t < tokens.length; t++) {
    		var p2 = orgText.indexOf(tokens[t][0], p);
    		if (p2 < 0) {
    		    failed = true;
    		    console.log("WARNING: Cannot find location in text to use the suggestion.");
    		    break;
    		} else {
		    
    		    var curTokenStart = p2;
    		    var curTokenEnd = p2 + tokens[t][0].length - 1;
		    
    		    var marked = false;
    		    for (var m = 0; m < err.markings.length; m++) {
    			if (err.markings[m][0] <= t && err.markings[m][1] >= t) {
    			    marked = true;
    			    break;
    			}
    		    }
		    
    		    if (marked) {
    			// This token is marked by the error.
    			if (!insideMarking) {
    			    spansToKeep.push([lastSpanStart, curTokenStart - 1]);
    			    insideMarking = true;
    			}
    		    } else {
    			// This token is not marked by the error.
    			if (insideMarking) {
    			    insideMarking = false;
    			    lastSpanStart = lastTokenEnd + 1;
    			}
    		    }
		    
    		    lastTokenStart = curTokenStart;
    		    lastTokenEnd = curTokenEnd;
		    
    		    p = p2 + tokens[t][0].length;
    		}
    	    }
	    
    	    if (insideMarking) {
    		spansToKeep.push([lastTokenEnd + 1, orgText.length]);
    	    } else {
    		spansToKeep.push([lastSpanStart, orgText.length]);
    	    }
	    
    	    for (var sp = 0; sp < spansToKeep.length; sp++) {
    		if (spansToKeep[sp][0] >= 0 && spansToKeep[sp][1] >= 0) {
    		    newText += orgText.substring(spansToKeep[sp][0], spansToKeep[sp][1] + 1);
    		}
    		if (sp == 0) {
    		    newText += chosenSuggestion;
    		}
    	    }

    	    if(!failed) {
		stuffListenedTo[elemIdx].value = newText;

		newTexts();

		return newText;
    	    } else {
    		return "";
    	    }
	}
	return "";
    }
    
    // ---------------------------------------------------------------------------------
    // Listen to changes in the settings
    // ---------------------------------------------------------------------------------
    if(chrome.storage.sync.onChanged.hasListener(checkSettings)) {
	chrome.storage.sync.onChanged.removeListener(checkSettings);
    }
    chrome.storage.sync.onChanged.addListener(checkSettings);
    
    // Set messageFromPanel() as a listener for messages from the extension.
    chrome.runtime.onMessage.addListener(messageFromPanel);
})();
