var myWindowId;

// --------------------------------------------------------------------
// This is the HTML element in the popup window where we show the
// grammar checking results.
// --------------------------------------------------------------------
var granskaResultBox = document.querySelector("#granskaResults");

// ----------------------------------------------------------------------------------
// Handle settings
// ----------------------------------------------------------------------------------
document.addEventListener('DOMContentLoaded', function () {
    let showall = document.getElementById('grerr');

    chrome.storage.sync.get(["granskaOverleafShowall"], function (d) {
	if((d && d.granskaOverleafShowall)
	   || (!d || d.granskaOverleafShowall === undefined)) {
	    showall.checked = true;
	} else {
	    showall.checked = false;
	}
    });

    showall.addEventListener('change', function(){
	chrome.storage.sync.set({"granskaOverleafShowall":this.checked});
    });
});

// --------------------------------------------------------------------
// function storageListen(changes, area)
// --------------------------------------------------------------------
// We listen to the local storage. When the injected script wants to
// send us new data, typically when the user has edited some text, it
// sets the 'granskaPollFlag' to true, and we send a message to the
// injected script with a callback function for the script to use.
// --------------------------------------------------------------------
function storageListen(changes, area) {
    chrome.storage.sync.get(['granskaPollFlag'], function(d) {
	if(d && d.granskaPollFlag) {
	    // Reset the flag.
	    chrome.storage.sync.set({"granskaPollFlag":false});
	    
	    // Ask the injected script to send us the Overleaf text.
	    chrome.tabs.query({currentWindow: true, active: true}, function (tabs){
		var activeTab = tabs[0];
		chrome.tabs.sendMessage(activeTab.id, {"req":"sendTexts"}, textsFromPage);
	    });
	}
    });
}

// --------------------------------------------------------------------
// function messageFromPage(response)
// --------------------------------------------------------------------
// No longer used
// --------------------------------------------------------------------
function messageFromPage(response) {
    // console.log("got message from page, ", response);
}

// --------------------------------------------------------------------
// The text we last got from Overleaf
// --------------------------------------------------------------------
var seenTexts = [];

// --------------------------------------------------------------------
// function textsFromPage(response)
// --------------------------------------------------------------------
// Callback function for the injected script to use to send us the
// texts it has found.
// --------------------------------------------------------------------
function textsFromPage(response) {
    if(response) {
	var needToUpdate = false;

	popupMap = response.pm;
	suggMap = response.sm;
	
	// add more elements to 'seenTexts' if needed
	if(response.st.length >= seenTexts.length) {
	    for(var j = seenTexts.length; j <= response.st.length; j++) {
		seenTexts.push({"text":"", "se":false, "granska":[], "html":""});
	    }
	}
	
	for(var i = 0; i < response.st.length; i++) {
	    
	    var oldT = seenTexts[i];
	    var newT = response.st[i];

	    if(oldT.text != newT.text) {
		// if this text has been modified...
		if(newT.se || (oldT.se && oldT.html != "")) {
		    needToUpdate = true;
		}
		seenTexts[i] = response.st[i];
	    } else if(oldT.html != newT.html) {
		// if this html has been modified...
		needToUpdate = true;
		seenTexts[i] = response.st[i];
	    }
	}

	while(seenTexts.length > response.st.length) {
	    var oldT = seenTexts.pop();
	    if(oldT.se && oldT.html != "") {
		needToUpdate = true;
	    }
	}
	
	if(needToUpdate) {
	    updateHTML();
	}
    }
}

// ---------------------------------------------------------------------------------
// function updateHTML()
// ---------------------------------------------------------------------------------
// Update the HTML in the popup window.
// ---------------------------------------------------------------------------------
function updateHTML() {
    var res = "";
    
    for(var i = 0; i < seenTexts.length; i++) {
	if(seenTexts[i].se && seenTexts[i].html != "") {
	    if(res != "") {
		res += "<hr>";
	    }
	    res += seenTexts[i].html;
	}
    }

    if(!granskaResultBox) {
	granskaResultBox = document.querySelector("#granskaResults");
    }

    if (granskaResultBox) {
	granskaResultBox.innerHTML = res;

	// Go through the HTML and add functions to the elements that
	// should be clickable
	for(var p in popupMap) {
	    if(popupMap.hasOwnProperty(p)) {
		// for all text segments with some grammar checking
		// annotation, show the hidden info when the segment
		// is clicked
		var element = document.getElementById(p);
		if(element) {
		    element.addEventListener("click", function(event) {
			var source = event.target || event.srcElement;
			
			if(popupMap.hasOwnProperty(source.id)) {
			    var arg = popupMap[source.id];
			    var popup = document.getElementById(arg);
			    if(popup) {
				popup.classList.toggle("show");
			    }
			}
		    });

		    var arg = popupMap[p];
		    var pup = document.getElementById(arg);
		    if(pup) {
			pup.addEventListener("click", function(event) {
			    var source = event.target || event.srcElement;
			    if(source) {
				if(source.className == "granskaPopupText show") {
				    source.classList.toggle("show");
				} else if(source.className == "granskaPopupText-content") {
				    source.parentElement.classList.toggle("show");
				}
			    }
			});
		    }
		}
	    }
	}

	for(var p in suggMap) {
	    if(suggMap.hasOwnProperty(p)) {
		// For all suggested corrections from the grammar
		// checker, update the original text when the
		// suggestion is clicked.
		var element = document.getElementById(p);
		if(element) {
		    element.addEventListener("click", function(event) {
			var source = event.target || event.srcElement;
			
			if(suggMap.hasOwnProperty(source.id)) {
			    var arg = suggMap[source.id];

	    		    var s = arg[0]; // sentence no
	    		    var e = arg[1]; // error no
    	    		    var elemIdx = arg[2]; // seenTexts[elemIdx]
	    		    var sg = arg[3]; // suggestion text

			    if(elemIdx < seenTexts.length) {
				if(seenTexts[elemIdx].granska) {
    	    			    var sentences = seenTexts[elemIdx].granska;
				    
    	    			    if (sentences !== undefined && s < sentences.length) {
    	    				if (sentences[s].length > 2 && sentences[s][2].length > e) {
    	    				    pushChangeToElement(sentences, s, e, sg, elemIdx);
					}
				    }
				}
			    }
			}
		    });
		}
	    }
	}
	
    } else {
	console.log("WARNING: could not find the HTML element for Granska annotations.");
    }
    
    return res;
}

// ---------------------------------------------------------------------------------
// function pushChangeToElement(granskaSentences, sIdx, eIdx, chosenSuggestion, elemIdx)
// ---------------------------------------------------------------------------------
// When a suggested correction from the grammar checker is clicked,
// ask the injected script to update the original text in accordance
// with the suggestion.
// ---------------------------------------------------------------------------------
function pushChangeToElement(granskaSentences, sIdx, eIdx, chosenSuggestion, elemIdx) {
    chrome.tabs.query({currentWindow: true, active: true}, function (tabs){
	var activeTab = tabs[0];
	chrome.tabs.sendMessage(activeTab.id, {"req":"pushCorrectionToPage", "granskaSentences":granskaSentences, "sentIdx":sIdx, "errIdx":eIdx, "chosenSuggestion":chosenSuggestion, "elemIdx":elemIdx}, messageFromPage);
	chrome.tabs.sendMessage(activeTab.id, {"req":"sendTexts"}, textsFromPage);
    });
    
    return "";
}

// ----------------------------------------------------------------------------------
// popupMap stores information on what grammar checking annotation
// HTML element should get a callback function and what that function
// should do.
// ----------------------------------------------------------------------------------
// suggMap information on what grammar checking suggestion HTML
// element should get a callback function and what that function
// should do.
// ----------------------------------------------------------------------------------
var popupMap = {};
var suggMap = {};

// --------------------------------------------------------------------
// content loaded listener
// --------------------------------------------------------------------
// When a page is loaded, reset our data and send a message to the
// injected script requesting any texts in the current web page.
// --------------------------------------------------------------------
document.addEventListener('DOMContentLoaded', function () {
    popupMap = {};
    suggMap = {};
    seenTexts = [];
    
    if(chrome.storage.sync.onChanged.hasListener(storageListen)) {
	chrome.storage.sync.onChanged.removeListener(storageListen);
    }
    chrome.storage.sync.onChanged.addListener(storageListen);
    
    chrome.tabs.query({currentWindow: true, active: true}, function (tabs){
	var activeTab = tabs[0];
	chrome.tabs.sendMessage(activeTab.id, {"req":"startListening"}, messageFromPage);
	// chrome.tabs.sendMessage(activeTab.id, {"req":"sendTexts", "force":true}, textsFromPage);
    });
});

// --------------------------------------------------------------------
// Show the grammar checking results if we already have some.
// --------------------------------------------------------------------
chrome.tabs.query({currentWindow: true, active: true}, function (tabs){
    var activeTab = tabs[0];
    chrome.tabs.sendMessage(activeTab.id, {"req":"sendTexts", "force":true}, textsFromPage);
});
